from abjad.tools.componenttools._Component import _Component
from abjad.tools.marktools.Mark import Mark


class Comment(Mark):
    r'''.. versionadded:: 2.0

    User-defined comment::

        abjad> note = Note("c'4")

    ::

        abjad> marktools.Comment('this is a comment')(note)
        Comment('this is a comment')(c'4)

    ::

        abjad> f(note)
        % this is a comment
        c'4

    Comments implement ``__slots__``.
    '''

    __slots__ = ('_comment_name_string', '_format_slot', )

    def __init__(self, comment_name_string, format_slot = 'opening'):
        Mark.__init__(self)
        self._comment_name_string = comment_name_string
        self._format_slot = format_slot

    ### OVERLOADS ###

    def __copy__(self, *args):
        return type(self)(self._comment_name_string)

    __deepcopy__ = __copy__

    def __eq__(self, arg):
        if isinstance(arg, type(self)):
            return self._comment_name_string == arg._comment_name_string
        return False

    ### PRIVATE ATTRIBUTES ###

    @property
    def _contents_repr_string(self):
        return repr(self._comment_name_string)

    ### PUBLIC ATTRIBUTES ###

    @apply
    def contents_string( ):
        def fget(self):
            r'''Get contents string of comment::

                abjad> comment = marktools.Comment('comment contents string')
                abjad> comment.contents_string
                'comment contents string'

            Set contents string of comment::

                abjad> comment.contents_string = 'new comment contents string'
                abjad> comment.contents_string
                'new comment contents string'

            Set string.
            '''
            return self._comment_name_string
        def fset(self, contents_string):
            assert isinstance(contents_string, str)
            self._comment_name_string = contents_string
        return property(**locals( ))

    @property
    def format(self):
        '''Read-only LilyPond input format of comment:

        ::

            abjad> comment = marktools.Comment('this is a comment.')
            abjad> comment.format
            '% this is a comment.'

        Return string.
        '''
        from abjad.tools import iotools
        command = iotools.underscore_delimited_lowercase_to_lowercamelcase(self._comment_name_string)
        return r'%% %s' % command




from abjad import *


def test_instrumenttools_Piccolo_interval_of_transposition_01( ):

    piccolo = instrumenttools.Piccolo( )

    piccolo.interval_of_transposition == pitchtools.MelodicDiatonicInterval('+P8')



from abjad import *
import py.test


### TODO: Port forward to new style of tests. ###

### TEST TYPICAL DIVIDE ###

def test_tuplettools_make_tuplet_from_proportions_and_pair_01( ):
    t = tuplettools.make_tuplet_from_proportions_and_pair([1, 2, 4], (6, 16))
    assert str(t) == "{@ 7:6 c'16, c'8, c'4 @}"

def test_tuplettools_make_tuplet_from_proportions_and_pair_02( ):
    t = tuplettools.make_tuplet_from_proportions_and_pair([1, 1, 2, 4], (6, 16))
    assert str(t) == "{@ 4:3 c'16, c'16, c'8, c'4 @}"

def test_tuplettools_make_tuplet_from_proportions_and_pair_03( ):
    t = tuplettools.make_tuplet_from_proportions_and_pair([-2, 3, 7], (7, 16))
    assert str(t) == "{@ 12:7 r8, c'8., c'4.. @}"

def test_tuplettools_make_tuplet_from_proportions_and_pair_04( ):
    t = tuplettools.make_tuplet_from_proportions_and_pair([7, 7, -4, -1], (1, 4))
    assert str(t) == "{@ 19:16 c'16.., c'16.., r16, r64 @}"


### TEST DIVIDE, DOUBLE LIST ###

def test_tuplettools_make_tuplet_from_proportions_and_pair_05( ):
    t = tuplettools.make_tuplet_from_proportions_and_pair([1, 2, 2], (12, 16))
    assert str(t) == "{@ 5:6 c'8, c'4, c'4 @}"

def test_tuplettools_make_tuplet_from_proportions_and_pair_06( ):
    t = tuplettools.make_tuplet_from_proportions_and_pair([2, 4, 4], (12, 16))
    assert str(t) == "{@ 5:6 c'8, c'4, c'4 @}"

def test_tuplettools_make_tuplet_from_proportions_and_pair_07( ):
    t = tuplettools.make_tuplet_from_proportions_and_pair([4, 8, 8], (12, 16))
    assert str(t) == "{@ 5:3 c'4, c'2, c'2 @}"

def test_tuplettools_make_tuplet_from_proportions_and_pair_08( ):
    t = tuplettools.make_tuplet_from_proportions_and_pair([8, 16, 16], (12, 16))
    assert str(t) == "{@ 5:3 c'4, c'2, c'2 @}"


### TEST DIVIDE, DOUBLE NUMERATOR ###

def test_tuplettools_make_tuplet_from_proportions_and_pair_09( ):
    t = tuplettools.make_tuplet_from_proportions_and_pair([2, 4, 4], (3, 16))
    assert str(t) == "{@ 5:3 c'16, c'8, c'8 @}"

def test_tuplettools_make_tuplet_from_proportions_and_pair_10( ):
    t = tuplettools.make_tuplet_from_proportions_and_pair([2, 4, 4], (6, 16))
    assert str(t) == "{@ 5:3 c'8, c'4, c'4 @}"

def test_tuplettools_make_tuplet_from_proportions_and_pair_11( ):
    t = tuplettools.make_tuplet_from_proportions_and_pair([2, 4, 4], (12, 16))
    assert str(t) == "{@ 5:6 c'8, c'4, c'4 @}"

def test_tuplettools_make_tuplet_from_proportions_and_pair_12( ):
    t = tuplettools.make_tuplet_from_proportions_and_pair([2, 4, 4], (24, 16))
    assert str(t) == "{@ 5:6 c'4, c'2, c'2 @}"


### TEST DIVIDE, DOUBLE DENOMINATOR ###

def test_tuplettools_make_tuplet_from_proportions_and_pair_13( ):
    t = tuplettools.make_tuplet_from_proportions_and_pair([1, 2, 2], (6, 2))
    assert str(t) == "{@ 5:6 c'2, c'1, c'1 @}"

def test_tuplettools_make_tuplet_from_proportions_and_pair_14( ):
    t = tuplettools.make_tuplet_from_proportions_and_pair([1, 2, 2], (6, 4))
    assert str(t) == "{@ 5:6 c'4, c'2, c'2 @}"

def test_tuplettools_make_tuplet_from_proportions_and_pair_15( ):
    t = tuplettools.make_tuplet_from_proportions_and_pair([1, 2, 2], (6, 8))
    assert str(t) == "{@ 5:6 c'8, c'4, c'4 @}"

def test_tuplettools_make_tuplet_from_proportions_and_pair_16( ):
    t = tuplettools.make_tuplet_from_proportions_and_pair([1, 2, 2], (6, 16))
    assert str(t) == "{@ 5:6 c'16, c'8, c'8 @}"


### TEST DIVIDE, NO PROLATION ###

def test_tuplettools_make_tuplet_from_proportions_and_pair_17( ):
    t = tuplettools.make_tuplet_from_proportions_and_pair([1, -1, -1], (3, 16))
    assert str(t) == "{@ 1:1 c'16, r16, r16 @}"

def test_tuplettools_make_tuplet_from_proportions_and_pair_18( ):
    t = tuplettools.make_tuplet_from_proportions_and_pair([1, 1, -1, -1], (4, 16))
    assert str(t) == "{@ 1:1 c'16, c'16, r16, r16 @}"

def test_tuplettools_make_tuplet_from_proportions_and_pair_19( ):
    t = tuplettools.make_tuplet_from_proportions_and_pair([1, 1, 1, -1, -1], (5, 16))
    assert str(t) == "{@ 1:1 c'16, c'16, c'16, r16, r16 @}"

def test_tuplettools_make_tuplet_from_proportions_and_pair_20( ):
    t = tuplettools.make_tuplet_from_proportions_and_pair([1, 1, 1, 1, -1, -1], (6, 16))
    assert str(t) == "{@ 1:1 c'16, c'16, c'16, c'16, r16, r16 @}"


### TEST LONE DIVIDE ###

def test_tuplettools_make_tuplet_from_proportions_and_pair_21( ):
    t = tuplettools.make_tuplet_from_proportions_and_pair([1], (6, 16))
    assert str(t) == "{c'4.}"

def test_tuplettools_make_tuplet_from_proportions_and_pair_22( ):
    t = tuplettools.make_tuplet_from_proportions_and_pair([99], (6, 16))
    assert str(t) == "{c'4.}"

def test_tuplettools_make_tuplet_from_proportions_and_pair_23( ):
    t = tuplettools.make_tuplet_from_proportions_and_pair([-1], (6, 16))
    assert str(t) == "{r4.}"

def test_tuplettools_make_tuplet_from_proportions_and_pair_24( ):
    t = tuplettools.make_tuplet_from_proportions_and_pair([-99], (6, 16))
    assert str(t) == "{r4.}"


### TEST DIVIDE ASSERTIONS ###

def test_tuplettools_make_tuplet_from_proportions_and_pair_25( ):
    py.test.raises(ValueError, 'tuplettools.make_tuplet_from_proportions_and_pair([ ], (3, 16))')

def test_tuplettools_make_tuplet_from_proportions_and_pair_26( ):
    py.test.raises(ValueError, 'tuplettools.make_tuplet_from_proportions_and_pair([0], (3, 16))')

def test_tuplettools_make_tuplet_from_proportions_and_pair_27( ):
    py.test.raises(ValueError, 'tuplettools.make_tuplet_from_proportions_and_pair([1, 1, 0, 1], (3, 16))')



from abjad import *


def test_StaffLinesSpanner___eq___01( ):
    '''Spanner is strict comparator.
    '''

    spanner_1 = spannertools.StaffLinesSpanner( )
    spanner_2 = spannertools.StaffLinesSpanner( )

    assert not spanner_1 == spanner_2






from abjad import *


def test_MetricGridSpanner___init___01( ):
    '''Init empty metric grid spanner.
    '''

    metric_grid = spannertools.MetricGridSpanner( )
    assert isinstance(metric_grid, spannertools.MetricGridSpanner)






from abjad import *


def test_TimeSignatureMark_denominator_01( ):
    '''Time signature mark denominator is read / write.
    '''

    meter = contexttools.TimeSignatureMark(3, 8)
    assert meter.denominator == 8

    meter.denominator = 16
    assert meter.denominator == 16





from abjad import *
from abjad.tools import seqtools


def test_seqtools_partition_sequence_cyclically_by_weights_exactly_with_overhang_01( ):

    sequence = [3, 3, 3, 3, 4, 4, 4, 4, 5]
    groups = seqtools.partition_sequence_cyclically_by_weights_exactly_with_overhang(
        sequence, [12])
    assert groups == [[3, 3, 3, 3], [4, 4, 4], [4, 5]]



from abjad import *
from abjad.tools import durtools
import py.test


def test_durtools_assignable_rational_to_lilypond_duration_string_01( ):

    assert durtools.assignable_rational_to_lilypond_duration_string(Fraction(1, 16)) == '16'
    assert durtools.assignable_rational_to_lilypond_duration_string(Fraction(2, 16)) == '8'
    assert durtools.assignable_rational_to_lilypond_duration_string(Fraction(3, 16)) == '8.'
    assert durtools.assignable_rational_to_lilypond_duration_string(Fraction(4, 16)) == '4'


def test_durtools_assignable_rational_to_lilypond_duration_string_02( ):

    assert py.test.raises(AssignabilityError,
        'durtools.assignable_rational_to_lilypond_duration_string(Fraction(5, 16))')




from abjad import *
from abjad.tools import durtools
import py.test


def test_durtools_group_duration_tokens_by_implied_prolation_01( ):
    assert py.test.raises(
        AssertionError, 'durtools.group_duration_tokens_by_implied_prolation([ ])')


def test_durtools_group_duration_tokens_by_implied_prolation_02( ):
    t = durtools.group_duration_tokens_by_implied_prolation([(1, 4)])
    assert t == [[(1, 4)]]


def test_durtools_group_duration_tokens_by_implied_prolation_03( ):
    t = durtools.group_duration_tokens_by_implied_prolation([(1, 4), (1, 4), (1, 8)])
    assert t == [[(1, 4), (1, 4), (1, 8)]]


def test_durtools_group_duration_tokens_by_implied_prolation_04( ):
    t = durtools.group_duration_tokens_by_implied_prolation([(1, 4), (1, 3), (1, 8)])
    assert t == [[(1, 4)], [(1, 3)], [(1, 8)]]


def test_durtools_group_duration_tokens_by_implied_prolation_05( ):
    t = durtools.group_duration_tokens_by_implied_prolation([(1, 4), (1, 2), (1, 3)])
    assert t == [[(1, 4), (1, 2)], [(1, 3)]]


def test_durtools_group_duration_tokens_by_implied_prolation_06( ):
    t = durtools.group_duration_tokens_by_implied_prolation([(1, 4), (1, 2), (1, 3), (1, 6),
        (1, 5)])
    assert t == [[(1, 4), (1, 2)], [(1, 3), (1, 6)], [(1, 5)]]


def test_durtools_group_duration_tokens_by_implied_prolation_07( ):
    t = durtools.group_duration_tokens_by_implied_prolation([(1, 24), (2, 24), (3, 24),
        (4, 24), (5, 24), (6, 24)])
    assert t == [[(1, 24), (2, 24), (3, 24), (4, 24), (5, 24), (6, 24)]]




from abjad.tools.quantizationtools import QGrid


def test_quantizationtools_QGrid_find_divisible_indices_01( ):
    q = QGrid([0, [0, [0, [0, 0]]]], 0)
    assert q.find_divisible_indices([ ]) == [ ]
    assert q.find_divisible_indices([0]) == [ ]
    assert q.find_divisible_indices([0, 0.5]) == [ ]
    assert q.find_divisible_indices([0.25]) == [0]
    assert q.find_divisible_indices([0.25, 0.8, 0.99]) == [0, 2, 4]
    assert q.find_divisible_indices([1]) == [ ]
    assert q.find_divisible_indices([-0.1, 1.1]) == [ ]



from abjad.tools.intervaltreetools.BoundedInterval import BoundedInterval
import py.test


def test_BoundedInterval___init___01( ):
    '''High offset must be greater than low offset.'''
    py.test.raises(AssertionError,
        "i = BoundedInterval(0, -10, 'this should fail.')")

def test_BoundedInterval___init___02( ):
    '''BoundedIntervals cannot be instantiated from floats.'''
    py.test.raises(AssertionError,
        "i = BoundedInterval(0.5, 2.3, 'this should fail.')")

def test_BoundedInterval___init___03( ):
    '''BoundedIntervals can be instantiated from other intervals.'''
    i1 = BoundedInterval(0, 10, {'hello': 'world!'})
    i2 = BoundedInterval(i1)
    assert i1 == i2
    assert i1 is not i2

def test_BoundedInterval___init___04( ):
    '''BoundedIntervals can be instantiated with just a low and high offset.'''
    i = BoundedInterval(0, 10)

def test_BoundedInterval___init___05( ):
    '''BoundedIntervals can be instantiated with low offset, high offset and dictionary.'''
    i = BoundedInterval(0, 10, {'hello': 'world!'})

def test_BoundedInterval___init___06( ):
    '''BoundedIntervals must take a dictionary as their data argument.'''
    py.test.raises(AssertionError,
        'i = BoundedInterval(0, 10, "nope")')

def test_BoundedInterval___init___07( ):
    '''BoundedIntervals copy data on instantiation.'''
    data = { }
    i = BoundedInterval(0, 10, data)
    data['cat'] = 'dog'
    assert data != i



from abjad import *
from abjad.tools import seqtools


def test_seqtools_partition_sequence_by_ratio_of_lengths_01( ):

    parts = seqtools.partition_sequence_by_ratio_of_lengths(range(10), [1, 1, 2])
    assert parts == [[0, 1, 2], [3, 4], [5, 6, 7, 8, 9]]



from abjad.tools.intervaltreetools import *
from abjad.tools.intervaltreetools._make_test_intervals import _make_test_intervals


def test_IntervalTree___eq___01( ):
    a = IntervalTree(_make_test_intervals( ))
    b = IntervalTree(_make_test_intervals( ))
    assert a == b


def test_IntervalTree___eq___02( ):
    a = IntervalTree(_make_test_intervals( ))
    b = IntervalTree(_make_test_intervals( )[:-1])
    assert a != b


def test_IntervalTree___eq___03( ):
    a = IntervalTree([ ])
    b = IntervalTree([ ])
    assert a == b




from abjad import *


def test_Comment___init___01( ):
    '''Initialize LilyPond \slurDotted command.
    '''

    staff = Staff("c'8 d'8 e'8 f'8")
    slur = spannertools.SlurSpanner(staff.leaves)
    comment_mark = marktools.Comment('beginning of note content')(staff[0])

    r'''
    \new Staff {
        % beginning of note content
        c'8 (
        d'8
        e'8
        f'8 )
    }
    '''

    assert componenttools.is_well_formed_component(staff)
    assert staff.format == "\\new Staff {\n\t% beginning of note content\n\tc'8 (\n\td'8\n\te'8\n\tf'8 )\n}"




from abjad import *
from abjad.tools import seqtools


def test_seqtools_all_are_nonnegative_integer_powers_of_two_01( ):
    '''True when all elements in sequence are nonnegative integer powers of two.
    '''

    assert seqtools.all_are_nonnegative_integer_powers_of_two([1, 2, 256, 8, 16, 16, 16])


def test_seqtools_all_are_nonnegative_integer_powers_of_two_02( ):
    '''True on empty sequence.
    '''

    assert seqtools.all_are_nonnegative_integer_powers_of_two([ ])


def test_seqtools_all_are_nonnegative_integer_powers_of_two_03( ):
    '''False otherwise.
    '''

    assert not seqtools.all_are_nonnegative_integer_powers_of_two([3])
    assert not seqtools.all_are_nonnegative_integer_powers_of_two([1, 2, 4, 8, 16, 17])


def test_seqtools_all_are_nonnegative_integer_powers_of_two_04( ):
    '''False when expr is not a sequence.
    '''

    assert not seqtools.all_are_nonnegative_integer_powers_of_two(16)



from abjad import *


def test_instrumenttools_FrenchHorn_sounding_pitch_of_fingered_middle_c_01( ):

    french_horn = instrumenttools.FrenchHorn( )

    assert french_horn.sounding_pitch_of_fingered_middle_c == 'f'



from abjad import *
from abjad.tools import durtools


def test_durtools_is_duration_token_01( ):

    assert durtools.is_duration_token((5, 16))
    assert durtools.is_duration_token('8..')
    assert durtools.is_duration_token(Fraction(5, 16))
    assert durtools.is_duration_token(5)


def test_durtools_is_duration_token_02( ):

    assert not durtools.is_duration_token((5, 6, 7))
    assert not durtools.is_duration_token('9..')
    assert not durtools.is_duration_token('foo')




from abjad.tools.spannertools.Spanner._SpannerFormatInterface import _SpannerFormatInterface


class _BeamSpannerFormatInterface(_SpannerFormatInterface):

    def __init__(self, spanner):
        _SpannerFormatInterface.__init__(self, spanner)

    ### PUBLIC METHODS ###

    def _before(self, leaf):
        '''Spanner format contribution before leaf.'''
        result = [ ]
        result.extend(_SpannerFormatInterface._before(self, leaf))
        return result

    def _right(self, leaf):
        '''Spanner format contribution right of leaf.'''
        result = [ ]
        spanner = self.spanner
        if spanner._is_my_first_leaf(leaf):
            result.append('[')
        if spanner._is_my_last_leaf(leaf):
            result.append(']')
        return result






from abjad import *
from abjad.tools import metertools


def test_metertools_is_meter_with_equivalent_binary_representation_01( ):
    '''True when meter is binary or when meter is nonbinary
        but mathematically equivalent to some binary meter.'''

    assert not metertools.is_meter_with_equivalent_binary_representation(contexttools.TimeSignatureMark(1, 12))
    assert not metertools.is_meter_with_equivalent_binary_representation(contexttools.TimeSignatureMark(2, 12))
    assert metertools.is_meter_with_equivalent_binary_representation(contexttools.TimeSignatureMark(3, 12))
    assert not metertools.is_meter_with_equivalent_binary_representation(contexttools.TimeSignatureMark(4, 12))
    assert not metertools.is_meter_with_equivalent_binary_representation(contexttools.TimeSignatureMark(5, 12))
    assert metertools.is_meter_with_equivalent_binary_representation(contexttools.TimeSignatureMark(6, 12))
    assert not metertools.is_meter_with_equivalent_binary_representation(contexttools.TimeSignatureMark(7, 12))
    assert not metertools.is_meter_with_equivalent_binary_representation(contexttools.TimeSignatureMark(8, 12))
    assert metertools.is_meter_with_equivalent_binary_representation(contexttools.TimeSignatureMark(9, 12))
    assert not metertools.is_meter_with_equivalent_binary_representation(contexttools.TimeSignatureMark(10, 12))
    assert not metertools.is_meter_with_equivalent_binary_representation(contexttools.TimeSignatureMark(11, 12))
    assert metertools.is_meter_with_equivalent_binary_representation(contexttools.TimeSignatureMark(12, 12))


def test_metertools_is_meter_with_equivalent_binary_representation_02( ):
    '''True when meter is binary or when meter is nonbinary
        but mathematically equivalent to some binary meter.'''

    assert not metertools.is_meter_with_equivalent_binary_representation(contexttools.TimeSignatureMark(1, 14))
    assert not metertools.is_meter_with_equivalent_binary_representation(contexttools.TimeSignatureMark(2, 14))
    assert not metertools.is_meter_with_equivalent_binary_representation(contexttools.TimeSignatureMark(3, 14))
    assert not metertools.is_meter_with_equivalent_binary_representation(contexttools.TimeSignatureMark(4, 14))
    assert not metertools.is_meter_with_equivalent_binary_representation(contexttools.TimeSignatureMark(5, 14))
    assert not metertools.is_meter_with_equivalent_binary_representation(contexttools.TimeSignatureMark(6, 14))
    assert metertools.is_meter_with_equivalent_binary_representation(contexttools.TimeSignatureMark(7, 14))
    assert not metertools.is_meter_with_equivalent_binary_representation(contexttools.TimeSignatureMark(8, 14))
    assert not metertools.is_meter_with_equivalent_binary_representation(contexttools.TimeSignatureMark(9, 14))
    assert not metertools.is_meter_with_equivalent_binary_representation(contexttools.TimeSignatureMark(10, 14))
    assert not metertools.is_meter_with_equivalent_binary_representation(contexttools.TimeSignatureMark(11, 14))
    assert not metertools.is_meter_with_equivalent_binary_representation(contexttools.TimeSignatureMark(12, 14))
    assert not metertools.is_meter_with_equivalent_binary_representation(contexttools.TimeSignatureMark(13, 14))
    assert metertools.is_meter_with_equivalent_binary_representation(contexttools.TimeSignatureMark(14, 14))


def test_metertools_is_meter_with_equivalent_binary_representation_03( ):
    '''True for binary meters.'''

    assert metertools.is_meter_with_equivalent_binary_representation(contexttools.TimeSignatureMark(1, 8))
    assert metertools.is_meter_with_equivalent_binary_representation(contexttools.TimeSignatureMark(2, 8))
    assert metertools.is_meter_with_equivalent_binary_representation(contexttools.TimeSignatureMark(3, 8))
    assert metertools.is_meter_with_equivalent_binary_representation(contexttools.TimeSignatureMark(4, 8))
    assert metertools.is_meter_with_equivalent_binary_representation(contexttools.TimeSignatureMark(5, 8))
    assert metertools.is_meter_with_equivalent_binary_representation(contexttools.TimeSignatureMark(6, 8))
    assert metertools.is_meter_with_equivalent_binary_representation(contexttools.TimeSignatureMark(7, 8))
    assert metertools.is_meter_with_equivalent_binary_representation(contexttools.TimeSignatureMark(8, 8))





from abjad import *
from abjad.tools import metertools


def test_metertools_meter_to_binary_meter_01( ):
    '''Make n/12 meters into n/8 meters, where possible.'''

    assert metertools.meter_to_binary_meter(contexttools.TimeSignatureMark(1, 12)) == contexttools.TimeSignatureMark(1, 12)
    assert metertools.meter_to_binary_meter(contexttools.TimeSignatureMark(2, 12)) == contexttools.TimeSignatureMark(2, 12)
    assert metertools.meter_to_binary_meter(contexttools.TimeSignatureMark(3, 12)) == contexttools.TimeSignatureMark(2, 8)
    assert metertools.meter_to_binary_meter(contexttools.TimeSignatureMark(4, 12)) == contexttools.TimeSignatureMark(4, 12)
    assert metertools.meter_to_binary_meter(contexttools.TimeSignatureMark(5, 12)) == contexttools.TimeSignatureMark(5, 12)
    assert metertools.meter_to_binary_meter(contexttools.TimeSignatureMark(6, 12)) == contexttools.TimeSignatureMark(4, 8)


def test_metertools_meter_to_binary_meter_02( ):
    '''Make n/14 meters into n/8 meters, where possible.'''

    assert metertools.meter_to_binary_meter(contexttools.TimeSignatureMark(1, 14)) == contexttools.TimeSignatureMark(1, 14)
    assert metertools.meter_to_binary_meter(contexttools.TimeSignatureMark(2, 14)) == contexttools.TimeSignatureMark(2, 14)
    assert metertools.meter_to_binary_meter(contexttools.TimeSignatureMark(3, 14)) == contexttools.TimeSignatureMark(3, 14)
    assert metertools.meter_to_binary_meter(contexttools.TimeSignatureMark(4, 14)) == contexttools.TimeSignatureMark(4, 14)
    assert metertools.meter_to_binary_meter(contexttools.TimeSignatureMark(5, 14)) == contexttools.TimeSignatureMark(5, 14)
    assert metertools.meter_to_binary_meter(contexttools.TimeSignatureMark(6, 14)) == contexttools.TimeSignatureMark(6, 14)
    assert metertools.meter_to_binary_meter(contexttools.TimeSignatureMark(7, 14)) == contexttools.TimeSignatureMark(4, 8)


def test_metertools_meter_to_binary_meter_03( ):
    '''Make n/24 meters into n/16 meters, where possible.'''

    assert metertools.meter_to_binary_meter(contexttools.TimeSignatureMark(1, 24)) == contexttools.TimeSignatureMark(1, 24)
    assert metertools.meter_to_binary_meter(contexttools.TimeSignatureMark(2, 24)) == contexttools.TimeSignatureMark(2, 24)
    assert metertools.meter_to_binary_meter(contexttools.TimeSignatureMark(3, 24)) == contexttools.TimeSignatureMark(2, 16)
    assert metertools.meter_to_binary_meter(contexttools.TimeSignatureMark(4, 24)) == contexttools.TimeSignatureMark(4, 24)
    assert metertools.meter_to_binary_meter(contexttools.TimeSignatureMark(5, 24)) == contexttools.TimeSignatureMark(5, 24)
    assert metertools.meter_to_binary_meter(contexttools.TimeSignatureMark(6, 24)) == contexttools.TimeSignatureMark(4, 16)
    assert metertools.meter_to_binary_meter(contexttools.TimeSignatureMark(7, 24)) == contexttools.TimeSignatureMark(7, 24)
    assert metertools.meter_to_binary_meter(contexttools.TimeSignatureMark(8, 24)) == contexttools.TimeSignatureMark(8, 24)


def test_metertools_meter_to_binary_meter_04( ):
    '''Make n/24 meters into n/8 meters, where possible.'''

    assert metertools.meter_to_binary_meter(contexttools.TimeSignatureMark(1, 24), Duration(99)) == contexttools.TimeSignatureMark(1, 24)
    assert metertools.meter_to_binary_meter(contexttools.TimeSignatureMark(2, 24), Duration(99)) == contexttools.TimeSignatureMark(2, 24)
    assert metertools.meter_to_binary_meter(contexttools.TimeSignatureMark(3, 24), Duration(99)) == contexttools.TimeSignatureMark(1, 8)
    assert metertools.meter_to_binary_meter(contexttools.TimeSignatureMark(4, 24), Duration(99)) == contexttools.TimeSignatureMark(4, 24)
    assert metertools.meter_to_binary_meter(contexttools.TimeSignatureMark(5, 24), Duration(99)) == contexttools.TimeSignatureMark(5, 24)
    assert metertools.meter_to_binary_meter(contexttools.TimeSignatureMark(6, 24), Duration(99)) == contexttools.TimeSignatureMark(2, 8)
    assert metertools.meter_to_binary_meter(contexttools.TimeSignatureMark(7, 24), Duration(99)) == contexttools.TimeSignatureMark(7, 24)
    assert metertools.meter_to_binary_meter(contexttools.TimeSignatureMark(8, 24), Duration(99)) == contexttools.TimeSignatureMark(8, 24)





from abjad import *


def test_TrillSpanner___init___01( ):
    '''Init empty trill spanner.
    '''

    trill = spannertools.TrillSpanner( )
    assert isinstance(trill, spannertools.TrillSpanner)






from abjad import *


def test_Annotation___init___01( ):
    '''Initialize annotation with dictionary.
    '''

    annotation = marktools.Annotation('special dictionary', { })

    assert isinstance(annotation, marktools.Annotation)




from abjad.cfg import cfg


def get_abjad_version_string( ):
    '''.. versionadded:: 2.0

    Get Abjad version string::

        abjad> from abjad.tools import cfgtools

    ::

        abjad> cfgtools.get_abjad_version_string( )
        '1.1.2'

    Return string.
    '''

    return vars(cfg)['abjad_version_number']



from abjad import *
from abjad.tools import seqtools


def test_seqtools_is_permutation_01( ):

    assert seqtools.is_permutation([3, 0, 1, 2])
    assert seqtools.is_permutation([2, 3, 0, 1])
    assert seqtools.is_permutation([0, 1, 2, 3])


def test_seqtools_is_permutation_02( ):

    assert not seqtools.is_permutation([0, 0, 1, 2])
    assert not seqtools.is_permutation('foo')
    assert not seqtools.is_permutation(7)


def test_seqtools_is_permutation_03( ):

    assert seqtools.is_permutation([3, 0, 1, 2], length = 4)
    assert not seqtools.is_permutation([3, 0, 1, 2], length = 3)
    assert not seqtools.is_permutation([3, 0, 1, 2], length = 5)



from abjad import *


def test_pitchtools_calculate_harmonic_diatonic_interval_class_from_named_chromatic_pitch_to_named_chromatic_pitch_01( ):
    '''Ascending intervals greater than an octave.'''

    hdic = pitchtools.calculate_harmonic_diatonic_interval_class_from_named_chromatic_pitch_to_named_chromatic_pitch(
        pitchtools.NamedChromaticPitch(-3), pitchtools.NamedChromaticPitch(12))
    assert hdic == pitchtools.HarmonicDiatonicIntervalClass('minor', 3)

    hdic = pitchtools.calculate_harmonic_diatonic_interval_class_from_named_chromatic_pitch_to_named_chromatic_pitch(
        pitchtools.NamedChromaticPitch(-2), pitchtools.NamedChromaticPitch(12))
    assert hdic == pitchtools.HarmonicDiatonicIntervalClass('major', 2)

    hdic = pitchtools.calculate_harmonic_diatonic_interval_class_from_named_chromatic_pitch_to_named_chromatic_pitch(
        pitchtools.NamedChromaticPitch(-1), pitchtools.NamedChromaticPitch(12))
    assert hdic == pitchtools.HarmonicDiatonicIntervalClass('minor', 2)


def test_pitchtools_calculate_harmonic_diatonic_interval_class_from_named_chromatic_pitch_to_named_chromatic_pitch_02( ):
    '''Ascending octave.'''

    hdic = pitchtools.calculate_harmonic_diatonic_interval_class_from_named_chromatic_pitch_to_named_chromatic_pitch(
        pitchtools.NamedChromaticPitch(0), pitchtools.NamedChromaticPitch(12))
    assert hdic == pitchtools.HarmonicDiatonicIntervalClass('perfect', 8)


def test_pitchtools_calculate_harmonic_diatonic_interval_class_from_named_chromatic_pitch_to_named_chromatic_pitch_03( ):
    '''Ascending intervals less than an octave.'''

    hdic = pitchtools.calculate_harmonic_diatonic_interval_class_from_named_chromatic_pitch_to_named_chromatic_pitch(
        pitchtools.NamedChromaticPitch(9), pitchtools.NamedChromaticPitch(12))
    assert hdic == pitchtools.HarmonicDiatonicIntervalClass('minor', 3)

    hdic = pitchtools.calculate_harmonic_diatonic_interval_class_from_named_chromatic_pitch_to_named_chromatic_pitch(
        pitchtools.NamedChromaticPitch(10), pitchtools.NamedChromaticPitch(12))
    assert hdic == pitchtools.HarmonicDiatonicIntervalClass('major', 2)

    hdic = pitchtools.calculate_harmonic_diatonic_interval_class_from_named_chromatic_pitch_to_named_chromatic_pitch(
        pitchtools.NamedChromaticPitch(11), pitchtools.NamedChromaticPitch(12))
    assert hdic == pitchtools.HarmonicDiatonicIntervalClass('minor', 2)


def test_pitchtools_calculate_harmonic_diatonic_interval_class_from_named_chromatic_pitch_to_named_chromatic_pitch_04( ):
    '''Unison.'''

    hdic = pitchtools.calculate_harmonic_diatonic_interval_class_from_named_chromatic_pitch_to_named_chromatic_pitch(
        pitchtools.NamedChromaticPitch(12), pitchtools.NamedChromaticPitch(12))
    assert hdic == pitchtools.HarmonicDiatonicIntervalClass('perfect', 1)


def test_pitchtools_calculate_harmonic_diatonic_interval_class_from_named_chromatic_pitch_to_named_chromatic_pitch_05( ):
    '''Descending intervals greater than an octave.'''

    hdic = pitchtools.calculate_harmonic_diatonic_interval_class_from_named_chromatic_pitch_to_named_chromatic_pitch(
        pitchtools.NamedChromaticPitch(12), pitchtools.NamedChromaticPitch(-3))
    assert hdic == pitchtools.HarmonicDiatonicIntervalClass('minor', 3)

    hdic = pitchtools.calculate_harmonic_diatonic_interval_class_from_named_chromatic_pitch_to_named_chromatic_pitch(
        pitchtools.NamedChromaticPitch(12), pitchtools.NamedChromaticPitch(-2))
    assert hdic == pitchtools.HarmonicDiatonicIntervalClass('major', 2)

    hdic = pitchtools.calculate_harmonic_diatonic_interval_class_from_named_chromatic_pitch_to_named_chromatic_pitch(
        pitchtools.NamedChromaticPitch(12), pitchtools.NamedChromaticPitch(-1))
    assert hdic == pitchtools.HarmonicDiatonicIntervalClass('minor', 2)


def test_pitchtools_calculate_harmonic_diatonic_interval_class_from_named_chromatic_pitch_to_named_chromatic_pitch_06( ):
    '''Descending octave.'''

    hdic = pitchtools.calculate_harmonic_diatonic_interval_class_from_named_chromatic_pitch_to_named_chromatic_pitch(
        pitchtools.NamedChromaticPitch(12), pitchtools.NamedChromaticPitch(0))
    assert hdic == pitchtools.HarmonicDiatonicIntervalClass('perfect', 8)


def test_pitchtools_calculate_harmonic_diatonic_interval_class_from_named_chromatic_pitch_to_named_chromatic_pitch_07( ):
    '''Descending intervals less than an octave.'''

    hdic = pitchtools.calculate_harmonic_diatonic_interval_class_from_named_chromatic_pitch_to_named_chromatic_pitch(
        pitchtools.NamedChromaticPitch(12), pitchtools.NamedChromaticPitch(9))
    assert hdic == pitchtools.HarmonicDiatonicIntervalClass('minor', 3)

    hdic = pitchtools.calculate_harmonic_diatonic_interval_class_from_named_chromatic_pitch_to_named_chromatic_pitch(
        pitchtools.NamedChromaticPitch(12), pitchtools.NamedChromaticPitch(10))
    assert hdic == pitchtools.HarmonicDiatonicIntervalClass('major', 2)

    hdic = pitchtools.calculate_harmonic_diatonic_interval_class_from_named_chromatic_pitch_to_named_chromatic_pitch(
        pitchtools.NamedChromaticPitch(12), pitchtools.NamedChromaticPitch(11))
    assert hdic == pitchtools.HarmonicDiatonicIntervalClass('minor', 2)




def negate_sequence_elements_at_indices(sequence, indices):
    '''.. versionadded:: 1.1.1

    Negate `sequence` elements at `indices`::

        abjad> from abjad.tools import seqtools

    ::

        abjad> sequence = [1, 2, 3, 4, 5, -6, -7, -8, -9, -10]

    ::

        abjad> seqtools.negate_sequence_elements_at_indices(sequence, [0, 1, 2])
        [-1, -2, -3, 4, 5, -6, -7, -8, -9, -10]

    Return newly constructed list.

    .. versionchanged:: 2.0
        renamed ``seqtools.negate_elements_at_indices( )`` to
        ``seqtools.negate_sequence_elements_at_indices( )``.
    '''

    if not isinstance(sequence, list):
        raise TypeError

    result = [ ]

    for i, element in enumerate(sequence):
        if (i in indices):
            result.append(-element)
        else:
            result.append(element)

    return result



from abjad import *
from abjad.tools import seqtools


def test_seqtools_yield_all_k_ary_sequences_of_length_01( ):

    generator = seqtools.yield_all_k_ary_sequences_of_length(2, 3)

    assert generator.next( ) == (0, 0, 0)
    assert generator.next( ) == (0, 0, 1)
    assert generator.next( ) == (0, 1, 0)
    assert generator.next( ) == (0, 1, 1)
    assert generator.next( ) == (1, 0, 0)
    assert generator.next( ) == (1, 0, 1)
    assert generator.next( ) == (1, 1, 0)
    assert generator.next( ) == (1, 1, 1)



from abjad.tools.durtools import Offset
from abjad.tools.intervaltreetools import *
from abjad.tools.intervaltreetools._make_test_intervals import _make_test_intervals


def test_intervaltreetools_calculate_mean_release_of_intervals_01( ):
    tree = IntervalTree(_make_test_intervals( ))
    release = calculate_mean_release_of_intervals(tree)
    assert release == Offset(sum([x.high for x in tree]), len(tree))


def test_intervaltreetools_calculate_mean_release_of_intervals_02( ):
    tree = IntervalTree([ ])
    release = calculate_mean_release_of_intervals(tree)
    assert release is None




from abjad import *
from abjad.tools import durtools


def test_durtools_is_lilypond_duration_name_01( ):

    assert durtools.is_lilypond_duration_name(r'\breve')
    assert durtools.is_lilypond_duration_name(r'\longa')
    assert durtools.is_lilypond_duration_name(r'\maxima')


def test_durtools_is_lilypond_duration_name_02( ):

    assert not durtools.is_lilypond_duration_name('breve')
    assert not durtools.is_lilypond_duration_name('foo')
    assert not durtools.is_lilypond_duration_name(12)




from abjad import *
from abjad.tools import seqtools


def test_seqtools_iterate_sequence_pairwise_cyclic_01( ):
    '''Cyclic pairwise.'''

    t = range(6)
    pairs = seqtools.iterate_sequence_pairwise_cyclic(t)
    for x in range(100):
        assert pairs.next( )



from abjad import *
from abjad.tools import seqtools


def test_seqtools_all_are_integer_equivalent_numbers_01( ):

    assert seqtools.all_are_integer_equivalent_numbers([1, 2, 3.0, Fraction(4)])


def test_seqtools_all_are_integer_equivalent_numbers_02( ):

    assert not seqtools.all_are_integer_equivalent_numbers([1, 2, 3.5, 4])
    assert not seqtools.all_are_integer_equivalent_numbers([1, 2, 3, Fraction(4, 11)])
    assert not seqtools.all_are_integer_equivalent_numbers(7)
    assert not seqtools.all_are_integer_equivalent_numbers('foo')



from abjad import *
from abjad.tools import cfgtools


def test_cfgtools_get_lilypond_version_string_01( ):

    lilypond_version_string = cfgtools.get_lilypond_version_string( )
    assert isinstance(lilypond_version_string, str)
    assert lilypond_version_string.count('.') == 2



from abjad.tools.leaftools._Leaf import _Leaf
from abjad.tools import componenttools
from abjad.tools import pitchtools


def label_leaves_in_expr_with_inversion_equivalent_chromatic_interval_classes(
    expr, markup_direction = 'up'):
    r""".. versionadded:: 2.0

    Label leaves in `expr` with inversion-equivalent chromatic interval classes::

        abjad> staff = Staff(notetools.make_notes([0, 25, 11, -4, -14, -13, 9, 10, 6, 5], [Duration(1, 8)]))
        abjad> leaftools.label_leaves_in_expr_with_inversion_equivalent_chromatic_interval_classes(staff)
        abjad> f(staff)
        \new Staff {
            c'8 ^ \markup { 1 }
            cs'''8 ^ \markup { 2 }
            b'8 ^ \markup { 2 }
            af8 ^ \markup { 2 }
            bf,8 ^ \markup { 1 }
            b,8 ^ \markup { 2 }
            a'8 ^ \markup { 1 }
            bf'8 ^ \markup { 4 }
            fs'8 ^ \markup { 1 }
            f'8
        }

    Return none.
    """
    from abjad.tools import threadtools
    from abjad.tools import markuptools
    from abjad.tools.notetools.Note import Note

    for note in componenttools.iterate_components_forward_in_expr(expr, Note):
        thread_iterator = threadtools.iterate_thread_forward_from_component(note, _Leaf)
        try:
            thread_iterator.next( )
            next_leaf = thread_iterator.next( )
            if isinstance(next_leaf, Note):
                mdi = note.written_pitch - next_leaf.written_pitch
                iecic = mdi.inversion_equivalent_chromatic_interval_class
                markuptools.Markup(iecic, markup_direction)(note)
        except StopIteration:
            pass





from abjad.tools.marktools.Mark import Mark


### TODO: extend LilyPond command marks to attach to spanners.
class LilyPondCommandMark(Mark):
    r'''.. versionadded:: 2.0

    LilyPond command mark::

        abjad> staff = Staff("c'8 d'8 e'8 f'8")
        abjad> slur = spannertools.SlurSpanner(staff.leaves)

    ::

        abjad> lilypond_command = marktools.LilyPondCommandMark('slurDotted')(staff[0])

    ::

        abjad> f(staff)
        \new Staff {
            \slurDotted
            c'8 (
            d'8
            e'8
            f'8 )
        }

    LilyPond command marks implement ``__slots__``.
    '''

    __slots__ = ('_command_name_string', '_format_slot', )

    def __init__(self, command_name_string, format_slot = 'opening'):
        Mark.__init__(self)
        self._command_name_string = command_name_string
        self._format_slot = format_slot

    ### OVERLOADS ###

    def __copy__(self, *args):
        return type(self)(self._command_name_string)

    __deepcopy__ = __copy__

    def __eq__(self, arg):
        if isinstance(arg, type(self)):
            return self._command_name_string == arg._command_name_string
        return False

    ### PRIVATE ATTRIBUTES ###

    @property
    def _contents_repr_string(self):
        return repr(self.command_name_string)

    ### PUBLIC ATTRIBUTES ###

    @apply
    def command_name_string( ):
        def fget(self):
            '''Get command name string of LilyPond command mark::

                abjad> lilypond_command = marktools.LilyPondCommandMark('slurDotted')
                abjad> lilypond_command.command_name_string
                'slurDotted'

            Set command name string of LilyPond command mark::

                abjad> lilypond_command.command_name_string = 'slurDashed'
                abjad> lilypond_command.command_name_string
                'slurDashed'

            Set string.
            '''
            return self._command_name_string
        def fset(self, command_name_string):
            assert isinstance(command_name_string, str)
            self._command_name_string = command_name_string
        return property(**locals( ))

    @property
    def format(self):
        '''Read-only LilyPond input format of LilyPond command mark::

            abjad> note = Note("c'4")
            abjad> lilypond_command = marktools.LilyPondCommandMark('slurDotted')(note)
            abjad> lilypond_command.format
            '\\slurDotted'

        Return string.
        '''
        from abjad.tools import iotools
        command = self._command_name_string
        if command.startswith('#'):
            return command
        else:
            return '\\' + iotools.underscore_delimited_lowercase_to_lowercamelcase(command)




from abjad import *
from abjad.tools import seqtools


def test_seqtools_is_repetition_free_sequence_01( ):

    assert seqtools.is_repetition_free_sequence(range(6))


def test_seqtools_is_repetition_free_sequence_02( ):

    assert not seqtools.is_repetition_free_sequence([0, 1, 2, 2, 4, 5])


def test_seqtools_is_repetition_free_sequence_03( ):
    '''True when expr is an empty sequence.'''

    assert seqtools.is_repetition_free_sequence([ ])


def test_seqtools_is_repetition_free_sequence_04( ):
    '''False when expr is not a sequence.'''

    assert not seqtools.is_repetition_free_sequence(17)



from abjad import *
from abjad.tools import cfgtools


def test_cfgtools_list_abjad_templates_01( ):

    templates = cfgtools.list_abjad_templates( )

    assert all([isinstance(x, str) for x in templates])



from abjad import *


def test_TextScriptSpanner___init___01( ):
    '''Init empty text script spanner.
    '''

    spanner = spannertools.TextScriptSpanner( )
    assert isinstance(spanner, spannertools.TextScriptSpanner)






from abjad import *
from abjad.tools import seqtools


def test_seqtools_partition_sequence_by_ratio_of_weights_01( ):
    '''Common cases.'''

    l = [1] * 10

    result = seqtools.partition_sequence_by_ratio_of_weights(l, [1, 1, 1])
    assert result == [[1, 1, 1], [1, 1, 1, 1], [1, 1, 1]]

    result = seqtools.partition_sequence_by_ratio_of_weights(l, [1, 1, 1, 1])
    assert result == [[1, 1, 1], [1, 1], [1, 1, 1], [1, 1]]

    result = seqtools.partition_sequence_by_ratio_of_weights(l, [2, 2, 3])
    assert result == [[1, 1, 1], [1, 1, 1], [1, 1, 1, 1]]

    result = seqtools.partition_sequence_by_ratio_of_weights(l, [3, 2, 2])
    assert result == [[1, 1, 1, 1], [1, 1, 1], [1, 1, 1]]


def test_seqtools_partition_sequence_by_ratio_of_weights_02( ):
    '''Unusual cases.'''

    l = [5, 5]

    result = seqtools.partition_sequence_by_ratio_of_weights(l, [1, 1, 1])
    assert result == [[5], [5], [ ]]

    result = seqtools.partition_sequence_by_ratio_of_weights(l, [1, 1, 1, 1])
    assert result == [[5], [ ], [5], [ ]]

    result = seqtools.partition_sequence_by_ratio_of_weights(l, [2, 2, 3])
    assert result == [[5], [5], [ ]]

    result = seqtools.partition_sequence_by_ratio_of_weights(l, [3, 2, 2])
    assert result == [[5], [5], [ ]]


def test_seqtools_partition_sequence_by_ratio_of_weights_03( ):
    '''More unusual cases.'''

    l = [7, 3]

    result = seqtools.partition_sequence_by_ratio_of_weights(l, [1, 1, 1])
    assert result == [[7], [ ], [3]]

    result = seqtools.partition_sequence_by_ratio_of_weights(l, [1, 1, 1, 1])
    assert result == [[7], [ ], [3], [ ]]

    result = seqtools.partition_sequence_by_ratio_of_weights(l, [2, 2, 3])
    assert result == [[7], [ ], [3]]

    result = seqtools.partition_sequence_by_ratio_of_weights(l, [3, 2, 2])
    assert result == [[7], [ ], [3]]



from abjad import *
from abjad.tools import seqtools


def test_seqtools_repeat_sequence_to_weight_at_most_01( ):

    assert seqtools.repeat_sequence_to_weight_at_most([5, -5, -5], 23) == [5, -5, -5, 5]



from abjad import *


def test_pitchtools_calculate_harmonic_chromatic_interval_from_pitch_carrier_to_pitch_carrier_01( ):
    '''Ascending intervals greater than an octave.'''

    hci = pitchtools.calculate_harmonic_chromatic_interval_from_pitch_carrier_to_pitch_carrier(
        pitchtools.NamedChromaticPitch(-3), pitchtools.NamedChromaticPitch(12))
    assert hci == pitchtools.HarmonicChromaticInterval(15)

    hci = pitchtools.calculate_harmonic_chromatic_interval_from_pitch_carrier_to_pitch_carrier(
        pitchtools.NamedChromaticPitch(-2), pitchtools.NamedChromaticPitch(12))
    assert hci == pitchtools.HarmonicChromaticInterval(14)

    hci = pitchtools.calculate_harmonic_chromatic_interval_from_pitch_carrier_to_pitch_carrier(
        pitchtools.NamedChromaticPitch(-1), pitchtools.NamedChromaticPitch(12))
    assert hci == pitchtools.HarmonicChromaticInterval(13)


def test_pitchtools_calculate_harmonic_chromatic_interval_from_pitch_carrier_to_pitch_carrier_02( ):
    '''Ascending octave.'''

    hci = pitchtools.calculate_harmonic_chromatic_interval_from_pitch_carrier_to_pitch_carrier(
        pitchtools.NamedChromaticPitch(0), pitchtools.NamedChromaticPitch(12))
    assert hci == pitchtools.HarmonicChromaticInterval(12)


def test_pitchtools_calculate_harmonic_chromatic_interval_from_pitch_carrier_to_pitch_carrier_03( ):
    '''Ascending intervals less than an octave.'''

    hci = pitchtools.calculate_harmonic_chromatic_interval_from_pitch_carrier_to_pitch_carrier(
        pitchtools.NamedChromaticPitch(9), pitchtools.NamedChromaticPitch(12))
    assert hci == pitchtools.HarmonicChromaticInterval(3)

    hci = pitchtools.calculate_harmonic_chromatic_interval_from_pitch_carrier_to_pitch_carrier(
        pitchtools.NamedChromaticPitch(10), pitchtools.NamedChromaticPitch(12))
    assert hci == pitchtools.HarmonicChromaticInterval(2)

    hci = pitchtools.calculate_harmonic_chromatic_interval_from_pitch_carrier_to_pitch_carrier(
        pitchtools.NamedChromaticPitch(11), pitchtools.NamedChromaticPitch(12))
    assert hci == pitchtools.HarmonicChromaticInterval(1)


def test_pitchtools_calculate_harmonic_chromatic_interval_from_pitch_carrier_to_pitch_carrier_04( ):
    '''Unison.'''

    hci = pitchtools.calculate_harmonic_chromatic_interval_from_pitch_carrier_to_pitch_carrier(
        pitchtools.NamedChromaticPitch(12), pitchtools.NamedChromaticPitch(12))
    assert hci == pitchtools.HarmonicChromaticInterval(0)


def test_pitchtools_calculate_harmonic_chromatic_interval_from_pitch_carrier_to_pitch_carrier_05( ):
    '''Descending intervals greater than an octave.'''

    hci = pitchtools.calculate_harmonic_chromatic_interval_from_pitch_carrier_to_pitch_carrier(
        pitchtools.NamedChromaticPitch(12), pitchtools.NamedChromaticPitch(-3))
    assert hci == pitchtools.HarmonicChromaticInterval(15)

    hci = pitchtools.calculate_harmonic_chromatic_interval_from_pitch_carrier_to_pitch_carrier(
        pitchtools.NamedChromaticPitch(12), pitchtools.NamedChromaticPitch(-2))
    assert hci == pitchtools.HarmonicChromaticInterval(14)

    hci = pitchtools.calculate_harmonic_chromatic_interval_from_pitch_carrier_to_pitch_carrier(
        pitchtools.NamedChromaticPitch(12), pitchtools.NamedChromaticPitch(-1))
    assert hci == pitchtools.HarmonicChromaticInterval(13)


def test_pitchtools_calculate_harmonic_chromatic_interval_from_pitch_carrier_to_pitch_carrier_06( ):
    '''Descending octave.'''

    hci = pitchtools.calculate_harmonic_chromatic_interval_from_pitch_carrier_to_pitch_carrier(
        pitchtools.NamedChromaticPitch(12), pitchtools.NamedChromaticPitch(0))
    assert hci == pitchtools.HarmonicChromaticInterval(12)


def test_pitchtools_calculate_harmonic_chromatic_interval_from_pitch_carrier_to_pitch_carrier_07( ):
    '''Descending intervals less than an octave.'''

    hci = pitchtools.calculate_harmonic_chromatic_interval_from_pitch_carrier_to_pitch_carrier(
        pitchtools.NamedChromaticPitch(12), pitchtools.NamedChromaticPitch(9))
    assert hci == pitchtools.HarmonicChromaticInterval(3)

    hci = pitchtools.calculate_harmonic_chromatic_interval_from_pitch_carrier_to_pitch_carrier(
        pitchtools.NamedChromaticPitch(12), pitchtools.NamedChromaticPitch(10))
    assert hci == pitchtools.HarmonicChromaticInterval(2)

    hci = pitchtools.calculate_harmonic_chromatic_interval_from_pitch_carrier_to_pitch_carrier(
        pitchtools.NamedChromaticPitch(12), pitchtools.NamedChromaticPitch(11))
    assert hci == pitchtools.HarmonicChromaticInterval(1)


def test_pitchtools_calculate_harmonic_chromatic_interval_from_pitch_carrier_to_pitch_carrier_08( ):
    '''Works with quartertones.'''

    hci = pitchtools.calculate_harmonic_chromatic_interval_from_pitch_carrier_to_pitch_carrier(
        pitchtools.NamedChromaticPitch(12), pitchtools.NamedChromaticPitch(-2.5))
    assert hci == pitchtools.HarmonicChromaticInterval(14.5)




from abjad import *
from abjad.tools import seqtools


def test_seqtools_retain_sequence_elements_at_indices_01( ):

    t = seqtools.retain_sequence_elements_at_indices(range(20), [1, 16, 17, 18])
    assert t == [1, 16, 17, 18]


def test_seqtools_retain_sequence_elements_at_indices_02( ):

    t = seqtools.retain_sequence_elements_at_indices(range(20), [ ])
    assert t == [ ]


def test_seqtools_retain_sequence_elements_at_indices_03( ):

    t = seqtools.retain_sequence_elements_at_indices(range(20), [99, 100, 101])
    assert t == [ ]



from abjad import *
import py.test


def test_LilyPondCommandMark___init___01( ):
    '''Initialize LilyPond \slurDotted command.
    '''

    staff = Staff("c'8 d'8 e'8 f'8")
    slur = spannertools.SlurSpanner(staff.leaves)
    lilypond_command = marktools.LilyPondCommandMark(r'slurDotted')(staff[0])


    r'''
    \new Staff {
        \slurDotted
        c'8 (
        d'8
        e'8
        f'8 )
    }
    '''

    assert componenttools.is_well_formed_component(staff)
    assert staff.format == "\\new Staff {\n\t\\slurDotted\n\tc'8 (\n\td'8\n\te'8\n\tf'8 )\n}"


def test_LilyPondCommandMark___init___02( ):
    '''Set LilyPond \slurUp command.
    '''

    staff = Staff("c'8 d'8 e'8 f'8")
    slur = spannertools.SlurSpanner(staff.leaves)
    lilypond_command = marktools.LilyPondCommandMark(r'slurUp')(staff[0])


    r'''
    \new Staff {
        \slurUp
        c'8 (
        d'8
        e'8
        f'8 )
    }
    '''

    assert componenttools.is_well_formed_component(staff)
    assert staff.format == "\\new Staff {\n\t\\slurUp\n\tc'8 (\n\td'8\n\te'8\n\tf'8 )\n}"




from abjad import *


def test_NumberedChromaticPitchClassSegment___mul___01( ):

    ncpcs1 = pitchtools.NumberedChromaticPitchClassSegment([0, 1, 11, 9])
    ncpsc2 = ncpcs1 * 2

    assert ncpsc2 == pitchtools.NumberedChromaticPitchClassSegment([0, 1, 11, 9, 0, 1, 11, 9])




from abjad.tools import seqtools
import py.test


def test_seqtools_truncate_sequence_to_sum_01( ):
    '''truncate_to_sum can take a list.'''

    t = seqtools.truncate_sequence_to_sum([2, 2, 2], 0)

    #assert t == [0]
    assert t == [ ]
    assert isinstance(t, list)


#def test_seqtools_truncate_sequence_to_sum_02( ):
#   '''truncate_to_sum can take a tuple.'''
#   t = seqtools.truncate_sequence_to_sum((2, 2, 2), 0)
#   assert t == (0, )
#   assert isinstance(t, tuple)


def test_seqtools_truncate_sequence_to_sum_03( ):
    '''Raise TypeError when l is not a list.'''

    assert py.test.raises(TypeError, "seqtools.truncate_sequence_to_sum('foo')")


def test_seqtools_truncate_sequence_to_sum_04( ):
    '''truncate_to_sum does work :-).'''

    ls = [2, 2, 1]

    t = seqtools.truncate_sequence_to_sum(ls, 1)
    assert t == [1]
    t = seqtools.truncate_sequence_to_sum(ls, 2)
    assert t == [2]
    t = seqtools.truncate_sequence_to_sum(ls, 3)
    assert t == [2, 1]
    t = seqtools.truncate_sequence_to_sum(ls, 4)
    assert t == [2, 2]
    t = seqtools.truncate_sequence_to_sum(ls, 5)
    assert t == [2, 2, 1]
    t = seqtools.truncate_sequence_to_sum(ls, 6)
    assert t == [2, 2, 1]


### ERRORS ###

def test_seqtools_truncate_sequence_to_sum_05( ):
    '''Raise ValueError on negative total.'''

    assert py.test.raises(ValueError,
        't = seqtools.truncate_sequence_to_sum([2, 2, 2], -1)')



from abjad import *


def test_BracketSpanner___eq___01( ):
    '''Spanner is strict comparator.
    '''

    spanner_1 = spannertools.BracketSpanner( )
    spanner_2 = spannertools.BracketSpanner( )

    assert not spanner_1 == spanner_2






from abjad import *


def test_TextSpanner___init___01( ):
    '''Init empty text spanner.
    '''

    spanner = spannertools.TextSpanner( )
    assert isinstance(spanner, spannertools.TextSpanner)






from abjad import *
from abjad.tools import seqtools


def test_seqtools_all_are_nonnegative_integer_equivalent_numbers_01( ):

    assert seqtools.all_are_nonnegative_integer_equivalent_numbers([0, 0.0, Fraction(0)])
    assert seqtools.all_are_nonnegative_integer_equivalent_numbers([2, 3, Fraction(4)])


def test_seqtools_all_are_nonnegative_integer_equivalent_numbers_02( ):

    assert not seqtools.all_are_nonnegative_integer_equivalent_numbers([-1, -2.0, Fraction(-3)])



from abjad import *
from abjad.tools import seqtools
import py.test


def test_seqtools_negate_absolute_value_of_sequence_elements_cyclically_01( ):

    l = [1, 2, 3, 4, 5, -6, -7, -8, -9, -10]
    t = seqtools.negate_absolute_value_of_sequence_elements_cyclically(l, [0, 1, 2], 5)

    assert t == [-1, -2, -3, 4, 5, -6, -7, -8, -9, -10]


def test_seqtools_negate_absolute_value_of_sequence_elements_cyclically_02( ):

    assert py.test.raises(TypeError,
        "seqtools.negate_absolute_value_of_sequence_elements_cyclically('foo', [0, 1, 2])")



from abjad import *


def test_NumberedChromaticPitchClassSet_is_transposed_superset_01( ):

    small = pitchtools.NumberedChromaticPitchClassSet([9, 10, 11])
    big = pitchtools.NumberedChromaticPitchClassSet([0, 1, 2, 3])

    assert big.is_transposed_superset(small)
    assert not small.is_transposed_superset(big)


def test_NumberedChromaticPitchClassSet_is_transposed_superset_02( ):

    small = pitchtools.NumberedChromaticPitchClassSet([5, 7, 9])
    big = pitchtools.NumberedChromaticPitchClassSet([0, 1, 2, 3])

    assert not big.is_transposed_superset(small)
    assert not small.is_transposed_superset(big)




from abjad import *
import py.test


def test_Mark___setattr___01( ):
    '''Slots constraint mark attributes.
    '''

    mark = marktools.Mark( )

    assert py.test.raises(AttributeError, "mark.foo = 'bar'")




from abjad import *
from abjad.tools import seqtools


def test_seqtools_get_sequence_degree_of_rotational_symmetry_01( ):

    assert seqtools.get_sequence_degree_of_rotational_symmetry([1, 2, 3, 4, 5, 6]) == 1
    assert seqtools.get_sequence_degree_of_rotational_symmetry([1, 2, 3, 1, 2, 3]) == 2
    assert seqtools.get_sequence_degree_of_rotational_symmetry([1, 2, 1, 2, 1, 2]) == 3
    assert seqtools.get_sequence_degree_of_rotational_symmetry([1, 1, 1, 1, 1, 1]) == 6



from abjad import *


def test_instrumenttools_Guitar_interval_of_transposition_01( ):

    guitar = instrumenttools.Guitar( )

    assert guitar.interval_of_transposition == pitchtools.MelodicDiatonicInterval('-P8')



from abjad.tools import contexttools
from abjad.tools import durtools
from abjad.tools import mathtools
import fractions


def meter_to_binary_meter(nonbinary_meter, contents_multiplier = fractions.Fraction(1)):
    '''Change nonbinary `meter` to binary meter::

        abjad> from abjad.tools import metertools

    ::

        abjad> metertools.meter_to_binary_meter(contexttools.TimeSignatureMark(3, 12))
        TimeSignatureMark(2, 8)

    Preserve binary `meter`::

        abjad> metertools.meter_to_binary_meter(contexttools.TimeSignatureMark(2, 8))
        TimeSignatureMark(2, 8)

    Return newly constructed meter.

    .. versionchanged:: 2.0
        renamed ``metertools.make_binary( )`` to
        ``metertools.meter_to_binary_meter( )``.
    '''

    ### check input
    assert isinstance(nonbinary_meter, contexttools.TimeSignatureMark)
    assert isinstance(contents_multiplier, fractions.Fraction)

    ### save nonbinary meter and denominator
    nonbinary_denominator = nonbinary_meter.denominator

    ### find binary denominator
    if contents_multiplier == fractions.Fraction(1):
        binary_denominator = mathtools.greatest_power_of_two_less_equal(nonbinary_denominator)
    else:
        binary_denominator = mathtools.greatest_power_of_two_less_equal(nonbinary_denominator, 1)

    ### find binary pair
    nonbinary_pair = (nonbinary_meter.numerator, nonbinary_meter.denominator)
    binary_pair = durtools.rational_to_duration_pair_with_specified_integer_denominator(
        nonbinary_pair, binary_denominator)

    ### return new binary meter
    return contexttools.TimeSignatureMark(*binary_pair)





from abjad import *
from abjad.tools import cfgtools


def test_cfgtools_get_python_version_string_01( ):


    python_version_string = cfgtools.get_python_version_string( )

    assert isinstance(python_version_string, str)
    assert python_version_string.count('.') == 2



from abjad import *
from abjad.tools import seqtools


def test_seqtools_all_are_numbers_01( ):
    '''True when all elements in sequence are numbers.
    '''

    assert seqtools.all_are_numbers([1, 2, 5.5, Fraction(8, 3)])


def test_seqtools_all_are_numbers_02( ):
    '''True on empty sequence.
    '''

    assert seqtools.all_are_numbers([ ])


def test_seqtools_all_are_numbers_03( ):
    '''False otherwise.
    '''

    assert not seqtools.all_are_numbers([1, 2, pitchtools.NamedChromaticPitch(3)])


def test_seqtools_all_are_numbers_04( ):
    '''False when expr is not a sequence.
    '''

    assert not seqtools.all_are_numbers(17)



from abjad import *
from abjad.tools import seqtools


def test_seqtools_all_are_positive_integers_01( ):

    assert seqtools.all_are_positive_integers([1, 2, 3, 99])


def test_seqtools_all_are_positive_integers_02( ):

    assert not seqtools.all_are_positive_integers([0, 2, 3, 99])
    assert not seqtools.all_are_positive_integers([-1, 2, 3, 99])
    assert not seqtools.all_are_positive_integers(7)
    assert not seqtools.all_are_positive_integers('foo')



from abjad.tools.intervaltreetools import *
from abjad.tools.intervaltreetools._make_test_intervals import _make_test_intervals


def test_intervaltreetools_all_are_intervals_or_trees_or_empty_01( ):
    tree = IntervalTree([ ])
    assert all_are_intervals_or_trees_or_empty(tree)


def test_intervaltreetools_all_are_intervals_or_trees_or_empty_02( ):
    interval = BoundedInterval(0, 10)
    assert all_are_intervals_or_trees_or_empty(interval)


def test_intervaltreetools_all_are_intervals_or_trees_or_empty_03( ):
    tree = IntervalTree([ ])
    other_tree = IntervalTree([BoundedInterval(2001, 2010)])
    interval = BoundedInterval(0, 10)
    assert all_are_intervals_or_trees_or_empty([tree, other_tree, interval])


def test_intervaltreetools_all_are_intervals_or_trees_or_empty_04( ):
    tree = IntervalTree([ ])
    other_tree = IntervalTree([BoundedInterval(2001, 2010)])
    interval = BoundedInterval(0, 10)
    assert all_are_intervals_or_trees_or_empty([tree, [[other_tree], interval], [ ]])


def test_intervaltreetools_all_are_intervals_or_trees_or_empty_05( ):
    tree = IntervalTree([ ])
    other_tree = IntervalTree([BoundedInterval(2001, 2010)])
    interval = BoundedInterval(0, 10)
    assert all_are_intervals_or_trees_or_empty([tree, [[other_tree], interval], [ ], [[interval]]])


def test_intervaltreetools_all_are_intervals_or_trees_or_empty_06( ):
    tree = IntervalTree([ ])
    other_tree = IntervalTree([BoundedInterval(2001, 2010)])
    interval = BoundedInterval(0, 10)
    assert not all_are_intervals_or_trees_or_empty([tree, [[other_tree], interval], [ ], [2]])


def test_intervaltreetools_all_are_intervals_or_trees_or_empty_07( ):
    assert all_are_intervals_or_trees_or_empty([ ])


def test_intervaltreetools_all_are_intervals_or_trees_or_empty_08( ):
    intervals = _make_test_intervals( )
    assert all_are_intervals_or_trees_or_empty(intervals)



from abjad import *


def test_GlissandoSpanner___init___01( ):
    '''Init empty glissando spanner.
    '''

    glissando = spannertools.GlissandoSpanner( )
    assert isinstance(glissando, spannertools.GlissandoSpanner)






from abjad import *


def test_LilyPondCommandMark_command_name_string_01( ):
    '''LilyPondCommandMark command name string is read / write.
    '''

    lilypond_command = marktools.LilyPondCommandMark('slurDotted')
    assert lilypond_command.command_name_string == 'slurDotted'

    lilypond_command.command_name_string = 'slurDashed'
    assert lilypond_command.command_name_string == 'slurDashed'




from abjad.tools import contexttools
from abjad.tools import pitchtools
from abjad.tools.instrumenttools.Oboe import Oboe


class EnglishHorn(Oboe):
    r'''.. versionadded:: 2.0

    Abjad model of the English horn::

        abjad> staff = Staff("c'8 d'8 e'8 f'8")

    ::

        abjad> instrumenttools.EnglishHorn( )(staff)
        EnglishHorn('English Horn', 'Eng. hn.')

    ::

        abjad> f(staff)
        \new Staff {
            \set Staff.instrumentName = \markup { English Horn }
            \set Staff.shortInstrumentName = \markup { Eng. hn. }
            c'8
            d'8
            e'8
            f'8
        }

    The English horn targets staff context by default.
    '''

    def __init__(self,
        instrument_name = 'English Horn', short_instrument_name = 'Eng. hn.', target_context = None):
        Oboe.__init__(self, instrument_name, short_instrument_name, target_context)
        self.sounding_pitch_of_fingered_middle_c = pitchtools.NamedChromaticPitch('f')
        self.primary_clefs = [contexttools.ClefMark('treble')]
        self._copy_primary_clefs_to_all_clefs( )
        self.traditional_range = (-8, 24)



from abjad import *
from abjad.tools import seqtools



def test_seqtools_flatten_sequence_at_indices_01( ):
    '''Works with positive indices.'''

    l = [0, 1, [2, 3, 4], [5, 6, 7]]
    t = seqtools.flatten_sequence_at_indices(l, [2])

    assert t == [0, 1, 2, 3, 4, [5, 6, 7]]


def test_seqtools_flatten_sequence_at_indices_02( ):
    '''Works with negative indices.'''

    l = [0, 1, [2, 3, 4], [5, 6, 7]]
    t = seqtools.flatten_sequence_at_indices(l, [-1])

    assert t == [0, 1, [2, 3, 4], 5, 6, 7]


def test_seqtools_flatten_sequence_at_indices_03( ):
    '''Boundary cases.'''

    l = [0, 1, [2, 3, 4], [5, 6, 7]]

    t = seqtools.flatten_sequence_at_indices(l, [ ])
    assert t == [0, 1, [2, 3, 4], [5, 6, 7]]

    t = seqtools.flatten_sequence_at_indices(l, [99])
    assert t == [0, 1, [2, 3, 4], [5, 6, 7]]

    t = seqtools.flatten_sequence_at_indices(l, [-99])
    assert t == [0, 1, [2, 3, 4], [5, 6, 7]]



from abjad import *
from abjad.tools import seqtools


def test_seqtools_all_are_nonnegative_integers_01( ):

    assert seqtools.all_are_nonnegative_integers([0, 1, 2, 3, 99])


def test_seqtools_all_are_nonnegative_integers_02( ):

    assert not seqtools.all_are_nonnegative_integers([-1, 2, 3, 99])
    assert not seqtools.all_are_nonnegative_integers(7)
    assert not seqtools.all_are_nonnegative_integers('foo')



from abjad.tools.intervaltreetools import *
from abjad.tools.intervaltreetools._make_test_intervals import _make_test_intervals
from abjad import Fraction


def test_intervaltreetools_calculate_depth_centroid_of_intervals_01( ):
    tree = IntervalTree(_make_test_intervals( ))
    result = calculate_depth_centroid_of_intervals(tree)
    assert result == Fraction(137, 8)


def test_intervaltreetools_calculate_depth_centroid_of_intervals_02( ):
    tree = IntervalTree([ ])
    result = calculate_depth_centroid_of_intervals(tree)
    assert result is None



def get_spanners_attached_to_any_proper_parent_of_component(component, klass = None):
    r'''.. versionadded:: 2.0

    Get all spanners attached to any proper parent of `component`::

        abjad> staff = Staff("c'8 d'8 e'8 f'8")
        abjad> beam = spannertools.BeamSpanner(staff.leaves)
        abjad> slur = spannertools.SlurSpanner(staff.leaves)
        abjad> trill = spannertools.TrillSpanner(staff)
        abjad> f(staff)
        \new Staff {
            c'8 [ ( \startTrillSpan
            d'8
            e'8
            f'8 ] ) \stopTrillSpan
        }

    ::

        abjad> spannertools.get_spanners_attached_to_any_proper_parent_of_component(staff[0])
        set([TrillSpanner({c'8, d'8, e'8, f'8})])

    Return unordered set of zero or more spanners.

    .. versionchanged:: 2.0
        renamed ``spannertools.get_all_spanners_attached_to_any_proper_parent_of_component( )`` to
        ``spannertools.get_spanners_attached_to_any_proper_parent_of_component( )``.
    '''
    from abjad.tools import componenttools

    result = set([ ])
    parentage = componenttools.get_proper_parentage_of_component(component)
    for parent in parentage:
        for spanner in parent.spanners:
            if klass is None:
                result.add(spanner)
            elif isinstance(spanner, klass):
                result.add(spanner)
    return result






from abjad import *


def test_componenttools_all_are_contiguous_components_01( ):
    '''True for strictly contiguous leaves in voice.
        False for other time orderings of leaves in voice.'''

    t = Voice("c'8 d'8 e'8 f'8")

    assert componenttools.all_are_contiguous_components(t.leaves)

    components = list(reversed(t.leaves))
    assert not componenttools.all_are_contiguous_components(components)

    components = [ ]
    components.extend(t.leaves[2:])
    components.extend(t.leaves[:2])
    assert not componenttools.all_are_contiguous_components(components)

    components = [ ]
    components.extend(t.leaves[3:4])
    components.extend(t.leaves[0:1])
    assert not componenttools.all_are_contiguous_components(components)

    components = [t]
    components.extend(t.leaves)
    assert not componenttools.all_are_contiguous_components(components)


def test_componenttools_all_are_contiguous_components_02( ):
    '''True for strictly contiguous components.'''

    t = Voice(Container(notetools.make_repeated_notes(2)) * 2)
    pitchtools.set_ascending_named_diatonic_pitches_on_nontied_pitched_components_in_expr(t)

    r'''
    \new Voice {
        {
            c'8
            d'8
        }
        {
            e'8
            f'8
        }
    }
    '''

    assert componenttools.all_are_contiguous_components([t])
    assert componenttools.all_are_contiguous_components(t[:])
    assert componenttools.all_are_contiguous_components(t[0][:])
    assert componenttools.all_are_contiguous_components(t[1][:])
    assert componenttools.all_are_contiguous_components(t[0:1] + t[1][:])
    assert componenttools.all_are_contiguous_components(t[0][:] + t[1:2])
    assert componenttools.all_are_contiguous_components(t.leaves)


def test_componenttools_all_are_contiguous_components_03( ):
    '''Unicorporated leaves can not be evaluated for contiguity.'''

    notes = [Note("c'8"), Note("d'8"), Note("e'8"), Note("f'8")]

    assert componenttools.all_are_contiguous_components(notes)
    assert not componenttools.all_are_contiguous_components(notes, allow_orphans = False)


def test_componenttools_all_are_contiguous_components_04( ):
    '''Empty list returns True.'''

    t = [ ]

    assert componenttools.all_are_contiguous_components(t)



from abjad import *
from abjad.tools import verticalitytools


def test_verticalitytools_label_vertical_moments_in_expr_with_interval_class_vectors_01( ):

    score = Score(Staff([ ]) * 3)
    notes = [Note("c'8"), Note("d'8"), Note("e'8"), Note("f'8")]
    score[0].extend(notes)
    contexttools.ClefMark('alto')(score[1])
    score[1].extend([Note(-5, (1, 4)), Note(-7, (1, 4))])
    contexttools.ClefMark('bass')(score[2])
    score[2].append(Note(-24, (1, 2)))
    verticalitytools.label_vertical_moments_in_expr_with_interval_class_vectors(score)

    r'''
    \new Score <<
        \new Staff {
            c'8
            d'8 _ \markup { \tiny { 0010020 } }
            e'8
            f'8 _ \markup { \tiny { 1000020 } }
        }
        \new Staff {
            \clef "alto"
            g4
            f4 _ \markup { \tiny { 0100110 } }
        }
        \new Staff {
            \clef "bass"
            c,2 _ \markup { \tiny { 1000020 } }
        }
    >>
    '''

    assert componenttools.is_well_formed_component(score)
    assert score.format == '\\new Score <<\n\t\\new Staff {\n\t\tc\'8\n\t\td\'8 _ \\markup { \\tiny { 0010020 } }\n\t\te\'8\n\t\tf\'8 _ \\markup { \\tiny { 1000020 } }\n\t}\n\t\\new Staff {\n\t\t\\clef "alto"\n\t\tg4\n\t\tf4 _ \\markup { \\tiny { 0100110 } }\n\t}\n\t\\new Staff {\n\t\t\\clef "bass"\n\t\tc,2 _ \\markup { \\tiny { 1000020 } }\n\t}\n>>'


def test_verticalitytools_label_vertical_moments_in_expr_with_interval_class_vectors_02( ):
    '''Vertical moments with quartertones format with a two-row
    interval-class vector. Top for 12-ET, bottom for 24-ET.'''

    chord = Chord([-2, -1.5, 9], (1, 4))
    verticalitytools.label_vertical_moments_in_expr_with_interval_class_vectors(chord)

    r'''
    <bf bqf a'>4 _ \markup { \tiny { \column { "0100000" "110000" } } }
    '''

    assert chord.format == '<bf bqf a\'>4 _ \\markup { \\tiny { \\column { "0100000" "110000" } } }'



from abjad import *
from abjad.tools import cfgtools


def test_cfgtools_list_abjad_environment_variables_01( ):

    environment_variables = cfgtools.list_abjad_environment_variables( )

    assert all([isinstance(x, tuple) for x in environment_variables])



import os


HOME = os.environ.get('HOME') or os.environ.get('APPDATA') or os.environ.get('HOMEPATH')
ABJADCONFIG = os.path.join(HOME, '.abjad', 'config.py')
ABJADPATH = os.path.abspath(os.path.dirname(__file__).rstrip('cfg'))
ABJADVERSIONFILE = os.path.join(ABJADPATH, '.version')

abjad_version_number = '1.1.2'



from abjad import *


def test_instrumenttools_Violin_sounding_pitch_of_fingered_middle_c_01( ):

    violin = instrumenttools.Violin( )

    assert violin.sounding_pitch_of_fingered_middle_c == "c'"



from abjad.tools import contexttools
from abjad.tools import pitchtools
from abjad.tools.instrumenttools._StringInstrument import _StringInstrument


class Guitar(_StringInstrument):
    r'''.. versionadded:: 2.0

    Abjad model of the guitar::

        abjad> staff = Staff("c'8 d'8 e'8 f'8")

    ::

        abjad> instrumenttools.Guitar( )(staff)
        Guitar('Guitar', 'Gt.')

    ::

        abjad> f(staff)
        \new Staff {
            \set Staff.instrumentName = \markup { Guitar }
            \set Staff.shortInstrumentName = \markup { Gt. }
            c'8
            d'8
            e'8
            f'8
        }

    The guitar targets staff context by default.
    '''

    def __init__(self,
        instrument_name = 'Guitar', short_instrument_name = 'Gt.', target_context = None):
        _StringInstrument.__init__(self, instrument_name, short_instrument_name, target_context)
        self.sounding_pitch_of_fingered_middle_c = pitchtools.NamedChromaticPitch('c')
        self.primary_clefs = [contexttools.ClefMark('treble')]
        self._copy_primary_clefs_to_all_clefs( )
        self.traditional_range = (-20, 16)



from abjad import *
from abjad.tools import seqtools
import py.test


def test_seqtools_flatten_sequence_01( ):
    l = [1, 2, 3, 4, 5]
    new = seqtools.flatten_sequence(l)
    assert new == [1, 2, 3, 4, 5]


def test_seqtools_flatten_sequence_02( ):
    l = [(1, 2), [3, 4]]
    new = seqtools.flatten_sequence(l)
    assert new == [1, 2, 3, 4]


def test_seqtools_flatten_sequence_03( ):
    l = [(1, 2), [3, (4, 5)]]
    new = seqtools.flatten_sequence(l)
    assert new == [1, 2, 3, 4, 5]


def test_seqtools_flatten_sequence_04( ):
    l = [(1, 2), [3, (4, 5)]]
    new = seqtools.flatten_sequence(l, klasses = (list, ))
    assert new == [(1, 2), 3, (4, 5)]


def test_seqtools_flatten_sequence_05( ):
    l = [(1, 2), [3, (4, 5)]]
    assert py.test.raises(AssertionError, 'seqtools.flatten_sequence(l, klasses = (tuple, ))')


def test_seqtools_flatten_sequence_06( ):
    l = [1, [2, 3, [4]], 5, [6, 7, [8]]]
    assert seqtools.flatten_sequence(l, depth = 0) == [1, [2, 3, [4]], 5, [6, 7, [8]]]
    assert seqtools.flatten_sequence(l, depth = 1) == [1, 2, 3, [4], 5, 6, 7, [8]]
    assert seqtools.flatten_sequence(l, depth = 2) == [1, 2, 3, 4, 5, 6, 7, 8]
    assert seqtools.flatten_sequence(l, depth = 2) == seqtools.flatten_sequence(l, depth = 99)



from abjad.tools import durtools


def get_first_element_starting_before_or_at_prolated_offset(container, prolated_offset):
    '''.. versionadded:: 2.0

    Get first `container` element starting before or at `prolated_offset`::

        abjad> staff = Staff("c'8 d'8 e'8 f'8")

    ::

        abjad> containertools.get_first_element_starting_before_or_at_prolated_offset(staff, Duration(1, 8))
        Note("d'8")

    Return component.

    Return none when no `container` element starts before or at `prolated_offset`.

    .. versionchanged:: 2.0
        renamed ``containertools.get_rightmost_element_starting_not_after_prolated_offset( )`` to
        ``containertools.get_first_element_starting_before_or_at_prolated_offset( )``.
    '''

    prolated_offset = durtools.Duration(prolated_offset)

    for element in reversed(container):
        if element._offset.start <= prolated_offset:
            return element



import subprocess


def get_python_version_string( ):
    '''.. versionadded:: 2.0

    Get Python version string::

        abjad> from abjad.tools import cfgtools

    ::

        abjad> cfgtools.get_python_version_string( ) # doctest: +SKIP
        '2.6.1'

    Return string.
    '''

    ### python prints to stderr on startup (instead of stdout)
    command = 'python --version'
    proc = subprocess.Popen(command, shell = True, stderr = subprocess.PIPE)
    python_version_string = proc.stderr.readline( )

    ### massage output string
    python_version_string = python_version_string.split(' ')[-1]
    python_version_string = python_version_string.strip( )

    ### return trimmed string
    return python_version_string



from abjad.tools.contexttools.ContextMark import ContextMark
from abjad.tools.contexttools.get_context_marks_attached_to_component import get_context_marks_attached_to_component


def is_component_with_context_mark_attached(component, klasses = (ContextMark, )):
    r'''.. versionadded:: 2.0

    True when context mark of `klasses` attaches to `component`::

        abjad> staff = Staff("c'8 d'8 e'8 f'8")
        abjad> contexttools.TimeSignatureMark(4, 8)(staff[0])
        TimeSignatureMark(4, 8)(c'8)
        abjad> f(staff)
        \new Staff {
            \time 4/8
            c'8
            d'8
            e'8
            f'8
        }
        abjad> contexttools.is_component_with_context_mark_attached(staff[0])
        True

    Otherwise false::

        abjad> contexttools.is_component_with_context_mark_attached(staff)
        False

    Return boolean.
    '''

    context_marks_attached = get_context_marks_attached_to_component(component, klasses = klasses)

    if 1 <= len(context_marks_attached):
        return True
    else:
        return False





from abjad.tools.componenttools._Component import _Component
from abjad.tools.marktools.Mark import Mark
import copy


class Annotation(Mark):
    r'''.. versionadded:: 2.0

    User-defined annotation::

        abjad> staff = Staff("c'8 d'8 e'8 f'8")

    ::

        abjad> f(staff)
        \new Staff {
            c'8
            d'8
            e'8
            f'8
        }

    ::

        abjad> marktools.Annotation('special pitch', pitchtools.NamedChromaticPitch('ds'))(staff[0])
        Annotation('special pitch', NamedChromaticPitch('ds'))(c'8)

    ::

        abjad> f(staff)
        \new Staff {
            c'8
            d'8
            e'8
            f'8
        }

    Annotations contribute no formatting.

    Annotations implement ``__slots__``.
    '''

    #__slots__ = ('_contents', '_format_slot', )
    __slots__ = ('_format_slot', '_name', '_value', )

    _format_slot = None

    #def __init__(self, contents):
    def __init__(self, name, value = None):
        Mark.__init__(self)
        #self._contents = copy.copy(contents)
        self._name = copy.copy(name)
        self._value = copy.copy(value)

    ### OVERLOADS ###

    def __copy__(self, *args):
        #return type(self)(self.contents_string)
        return type(self)(self.name, self.value)

    __deepcopy__ = __copy__

    def __eq__(self, arg):
        if isinstance(arg, type(self)):
            #return self.contents_string == arg.contents_string
            if self.name == arg.name:
                if self.value == self.value:
                    return True
        return False

    ### PRIVATE ATTRIBUTES ###

    @property
    def _contents_repr_string(self):
        #return repr(self.contents_string)
        if self.value is None:
            return repr(self.name)
        return ', '.join([repr(self.name), repr(self.value)])

    ### PUBLIC ATTRIBUTES ###

#   @apply
#   def contents_string( ):
#      def fget(self):
#         '''Get contents string of annotation::
#
#            abjad> annotation = marktools.Annotation('annotation contents')
#            abjad> annotation.contents_string
#            'annotation contents'
#
#         Set contents string of annotation::
#
#            abjad> annotation.contents_string = 'new annotation contents'
#            abjad> annotation.contents_string
#            'new annotation contents'
#         '''
#         return self._contents
#      def fset(self, contents_string):
#         assert isinstance(contents_string, str)
#         self._contents = contents_string
#      return property(**locals( ))

    @apply
    def name( ):
        def fget(self):
            '''Get name of annotation::

                abjad> annotation = marktools.Annotation('special_pitch', pitchtools.NamedChromaticPitch('ds'))
                abjad> annotation.name
                'special_pitch'

            Set name of annotation::

                abjad> annotation.name = 'revised special pitch'
                abjad> annotation.name
                'revised special pitch'

            Set string.
            '''
            return self._name
        def fset(self, name):
            assert isinstance(name, str)
            self._name = name
        return property(**locals( ))

    @apply
    def value( ):
        def fget(self):
            '''Get value of annotation::

                abjad> annotation = marktools.Annotation('special_pitch', pitchtools.NamedChromaticPitch('ds'))
                abjad> annotation.value
                NamedChromaticPitch('ds')

            Set value of annotation::

                abjad> annotation.value = pitchtools.NamedChromaticPitch('e')
                abjad> annotation.value
                NamedChromaticPitch('e')

            Set arbitrary object.
            '''
            return self._value
        def fset(self, value):
            self._value = value
        return property(**locals( ))




from abjad import *
from abjad.tools import durtools


def test_durtools_duration_tokens_to_least_common_denominator_01( ):

    tokens = [Fraction(2, 4), 3, '8.', (5, 16)]

    assert durtools.duration_tokens_to_least_common_denominator(tokens) == 16




from abjad import *


def test_instrumenttools_ContrabassFlute___init___01( ):

    contrabass_flute = instrumenttools.ContrabassFlute( )

    assert isinstance(contrabass_flute, instrumenttools.ContrabassFlute)



from abjad.tools.intervaltreetools import *
from abjad.tools.intervaltreetools._make_test_intervals import _make_test_intervals


def test_IntervalTree_find_intervals_starting_at_offset_01( ):
    blocks = _make_test_intervals( )
    target_offset = 0
    expected_payloads = ('a',)
    expected_blocks = tuple(sorted(filter(lambda x: x.keys( )[0] in expected_payloads, blocks),
        key = lambda x: x.signature))
    for i in range(len(blocks)):
        blocks.append(blocks.pop(0)) # rotate to permute tree construction
        tree = IntervalTree(blocks)
        actual_blocks = tree.find_intervals_starting_at_offset(target_offset)
        assert expected_blocks == actual_blocks

def test_IntervalTree_find_intervals_starting_at_offset_02( ):
    blocks = _make_test_intervals( )
    target_offset = 9
    expected_payloads = ( )
    expected_blocks = tuple(sorted(filter(lambda x: x.keys( )[0] in expected_payloads, blocks),
        key = lambda x: x.signature))
    for i in range(len(blocks)):
        blocks.append(blocks.pop(0)) # rotate to permute tree construction
        tree = IntervalTree(blocks)
        actual_blocks = tree.find_intervals_starting_at_offset(target_offset)
        assert expected_blocks == actual_blocks

def test_IntervalTree_find_intervals_starting_at_offset_03( ):
    blocks = _make_test_intervals( )
    target_offset = 14
    expected_payloads = ( )
    expected_blocks = tuple(sorted(filter(lambda x: x.keys( )[0] in expected_payloads, blocks),
        key = lambda x: x.signature))
    for i in range(len(blocks)):
        blocks.append(blocks.pop(0)) # rotate to permute tree construction
        tree = IntervalTree(blocks)
        actual_blocks = tree.find_intervals_starting_at_offset(target_offset)
        assert expected_blocks == actual_blocks

def test_IntervalTree_find_intervals_starting_at_offset_04( ):
    blocks = _make_test_intervals( )
    target_offset = 19
    expected_payloads = ('h',)
    expected_blocks = tuple(sorted(filter(lambda x: x.keys( )[0] in expected_payloads, blocks),
        key = lambda x: x.signature))
    for i in range(len(blocks)):
        blocks.append(blocks.pop(0)) # rotate to permute tree construction
        tree = IntervalTree(blocks)
        actual_blocks = tree.find_intervals_starting_at_offset(target_offset)
        assert expected_blocks == actual_blocks

def test_IntervalTree_find_intervals_starting_at_offset_05( ):
    blocks = _make_test_intervals( )
    target_offset = 26
    expected_payloads = ('j',)
    expected_blocks = tuple(sorted(filter(lambda x: x.keys( )[0] in expected_payloads, blocks),
        key = lambda x: x.signature))
    for i in range(len(blocks)):
        blocks.append(blocks.pop(0)) # rotate to permute tree construction
        tree = IntervalTree(blocks)
        actual_blocks = tree.find_intervals_starting_at_offset(target_offset)
        assert expected_blocks == actual_blocks

def test_IntervalTree_find_intervals_starting_at_offset_06( ):
    blocks = _make_test_intervals( )
    target_offset = 30
    expected_payloads = ( )
    expected_blocks = tuple(sorted(filter(lambda x: x.keys( )[0] in expected_payloads, blocks),
        key = lambda x: x.signature))
    for i in range(len(blocks)):
        blocks.append(blocks.pop(0)) # rotate to permute tree construction
        tree = IntervalTree(blocks)
        actual_blocks = tree.find_intervals_starting_at_offset(target_offset)
        assert expected_blocks == actual_blocks



from abjad import *


def test_pitchtools_chromatic_pitch_class_number_to_chromatic_pitch_class_name_with_sharps_01( ):

    assert pitchtools.chromatic_pitch_class_number_to_chromatic_pitch_class_name_with_sharps(0) == 'c'
    assert pitchtools.chromatic_pitch_class_number_to_chromatic_pitch_class_name_with_sharps(0.5) == 'cqs'
    assert pitchtools.chromatic_pitch_class_number_to_chromatic_pitch_class_name_with_sharps(1) == 'cs'
    assert pitchtools.chromatic_pitch_class_number_to_chromatic_pitch_class_name_with_sharps(1.5) == 'ctqs'
    assert pitchtools.chromatic_pitch_class_number_to_chromatic_pitch_class_name_with_sharps(2) == 'd'
    assert pitchtools.chromatic_pitch_class_number_to_chromatic_pitch_class_name_with_sharps(2.5) == 'dqs'




from abjad.tools import durtools
from abjad.tools import mathtools


def duration_and_possible_denominators_to_meter(duration, denominators = None, factor = None):
    '''Make new meter equal to `duration`::

        abjad> from abjad.tools import metertools

    ::

        abjad> metertools.duration_and_possible_denominators_to_meter(Duration(3, 2))
        TimeSignatureMark(3, 2)

    Make new meter equal to `duration` with denominator equal to the first possible element in `denominators`::

        abjad> metertools.duration_and_possible_denominators_to_meter(Duration(3, 2), denominators = [5, 6, 7, 8])
        TimeSignatureMark(9, 6)

    Make new meter equal to `duration` with denominator divisible by `factor`::

        abjad> metertools.duration_and_possible_denominators_to_meter(Duration(3, 2), factor = 5)
        TimeSignatureMark(15, 10)

    Return new meter.

    .. versionchanged:: 2.0
        renamed ``metertools.make_best( )`` to
        ``metertools.duration_and_possible_denominators_to_meter( )``.
    '''
    from abjad.tools import contexttools

    if denominators is not None:
        if factor is not None:
            denominators = [d for d in denominators if factor in mathtools.factors(d)]
        for desired_denominator in sorted(denominators):
            candidate_pair = durtools.rational_to_duration_pair_with_specified_integer_denominator(
                duration, desired_denominator)
            if candidate_pair[-1] == desired_denominator:
                return contexttools.TimeSignatureMark(candidate_pair)

    if factor is not None:
        if factor in mathtools.factors(duration.denominator):
            return contexttools.TimeSignatureMark(duration)
        else:
            meter_numerator = factor * duration.numerator
            meter_denominator = factor * duration.denominator
            return contexttools.TimeSignatureMark(meter_numerator, meter_denominator)
    else:
        return contexttools.TimeSignatureMark(duration)





from abjad import *


def test_StaffLinesSpanner___init___01( ):
    '''Init empty staff lines spanner.
    '''

    spanner = spannertools.StaffLinesSpanner( )
    assert isinstance(spanner, spannertools.StaffLinesSpanner)






from abjad import *


def test_componenttools_all_are_components_scalable_by_multiplier_01( ):
    t = [Note(0, (1, 8))]
    assert componenttools.all_are_components_scalable_by_multiplier(t, Duration(1, 2))


def test_componenttools_all_are_components_scalable_by_multiplier_02( ):
    t = [Note(0, (1, 8))]
    assert componenttools.all_are_components_scalable_by_multiplier(t, Duration(2, 1))


def test_componenttools_all_are_components_scalable_by_multiplier_03( ):
    t = [Note(0, (1, 8))]
    assert not componenttools.all_are_components_scalable_by_multiplier(t, Duration(2, 3))


def test_componenttools_all_are_components_scalable_by_multiplier_04( ):
    t = [Note(0, (1, 8))]
    assert componenttools.all_are_components_scalable_by_multiplier(t, Duration(3, 2))


def test_componenttools_all_are_components_scalable_by_multiplier_05( ):
    t = [Note(0, (3, 16))]
    assert componenttools.all_are_components_scalable_by_multiplier(t, Duration(2, 3))


def test_componenttools_all_are_components_scalable_by_multiplier_06( ):
    t = [Note(0, (3, 16))]
    assert not componenttools.all_are_components_scalable_by_multiplier(t, Duration(3, 2))



from abjad import *
from abjad.tools import seqtools


def test_seqtools_remove_sequence_elements_at_indices_01( ):

    t = list(seqtools.remove_sequence_elements_at_indices(range(20), [1, 16, 17, 18]))
    assert t == [0, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 19]


def test_seqtools_remove_sequence_elements_at_indices_02( ):

    t = list(seqtools.remove_sequence_elements_at_indices([ ], [1, 2, 3, 4, 5]))
    assert t == [ ]


def test_seqtools_remove_sequence_elements_at_indices_03( ):

    t = list(seqtools.remove_sequence_elements_at_indices(range(5), [ ]))
    assert t == [0, 1, 2, 3, 4]


def test_seqtools_remove_sequence_elements_at_indices_04( ):

    t = list(seqtools.remove_sequence_elements_at_indices(range(5), [99, 100, 101]))
    assert t == [0, 1, 2, 3, 4]


def test_seqtools_remove_sequence_elements_at_indices_05( ):

    t = list(seqtools.remove_sequence_elements_at_indices(range(5), [-1, -2, -3]))
    assert t == [0, 1, 2, 3, 4]



from abjad import *


def test_instrumenttools_EnglishHorn_sounding_pitch_of_fingered_middle_c_01( ):

    english_horn = instrumenttools.EnglishHorn( )

    assert english_horn.sounding_pitch_of_fingered_middle_c == 'f'



from abjad import *


def test_instrumenttools_AltoFlute_sounding_pitch_of_fingered_middle_c_01( ):

    alto_flute = instrumenttools.AltoFlute( )

    assert alto_flute.sounding_pitch_of_fingered_middle_c == 'g'



from abjad import *
from abjad.tools import metertools


def test_metertools_get_nonbinary_factor_from_meter_denominator_01( ):
    '''Return nonbinary factor in denominator of meter, else 1.'''

    assert metertools.get_nonbinary_factor_from_meter_denominator(contexttools.TimeSignatureMark(3, 12)) == 3
    assert metertools.get_nonbinary_factor_from_meter_denominator(contexttools.TimeSignatureMark(3, 18)) == 9
    assert metertools.get_nonbinary_factor_from_meter_denominator(contexttools.TimeSignatureMark(3, 19)) == 19
    assert metertools.get_nonbinary_factor_from_meter_denominator(contexttools.TimeSignatureMark(3, 20)) == 5
    assert metertools.get_nonbinary_factor_from_meter_denominator(contexttools.TimeSignatureMark(3, 21)) == 21
    assert metertools.get_nonbinary_factor_from_meter_denominator(contexttools.TimeSignatureMark(3, 24)) == 3
    assert metertools.get_nonbinary_factor_from_meter_denominator(contexttools.TimeSignatureMark(3, 28)) == 7


def test_metertools_get_nonbinary_factor_from_meter_denominator_02( ):
    '''Return nonbinary factor in denominator of meter, else 1.'''

    assert metertools.get_nonbinary_factor_from_meter_denominator(contexttools.TimeSignatureMark(3, 8)) == 1





def _get_stem_tremolo_format_contributions(component):
    '''.. versionadded:: 2.0
    '''
    from abjad.tools import marktools

    result = [ ]
    stem_tremolos = marktools.get_stem_tremolos_attached_to_component(component)
    for stem_tremolo in stem_tremolos:
        result.append(stem_tremolo.format)
    result.sort( )
    return ['stem tremolo', result]




from abjad import *
from abjad.tools import durtools


def test_durtools_yield_all_positive_integer_pairs_in_cantor_diagonalized_order_01( ):

    generator = durtools.yield_all_positive_integer_pairs_in_cantor_diagonalized_order( )

    assert generator.next( ) == (1, 1)
    assert generator.next( ) == (2, 1)
    assert generator.next( ) == (1, 2)
    assert generator.next( ) == (1, 3)
    assert generator.next( ) == (2, 2)
    assert generator.next( ) == (3, 1)
    assert generator.next( ) == (4, 1)
    assert generator.next( ) == (3, 2)
    assert generator.next( ) == (2, 3)
    assert generator.next( ) == (1, 4)
    assert generator.next( ) == (1, 5)
    assert generator.next( ) == (2, 4)




from abjad import *


def test_DuratedComplexBeamSpanner___init___01( ):
    '''Init empty durated complex beam spanner.
    '''

    beam = spannertools.DuratedComplexBeamSpanner( )
    assert isinstance(beam, spannertools.DuratedComplexBeamSpanner)






from abjad import *
from abjad.tools import durtools
import py.test


def test_durtools_assignable_rational_to_dot_count_01( ):

    assert durtools.assignable_rational_to_dot_count(Fraction(1, 16)) == 0
    assert durtools.assignable_rational_to_dot_count(Fraction(2, 16)) == 0
    assert durtools.assignable_rational_to_dot_count(Fraction(3, 16)) == 1
    assert durtools.assignable_rational_to_dot_count(Fraction(4, 16)) == 0

    assert durtools.assignable_rational_to_dot_count(Fraction(6, 16)) == 1
    assert durtools.assignable_rational_to_dot_count(Fraction(7, 16)) == 2
    assert durtools.assignable_rational_to_dot_count(Fraction(8, 16)) == 0


def test_durtools_assignable_rational_to_dot_count_02( ):

    assert py.test.raises(AssignabilityError,
        'durtools.assignable_rational_to_dot_count(Fraction(5, 16))')




from abjad import *


def test_instrumenttools_UntunedPercussion___init___01( ):

    percussion = instrumenttools.UntunedPercussion( )

    assert isinstance(percussion, instrumenttools.UntunedPercussion)



from abjad import *


def test_Articulation_name_string_01( ):

    a = marktools.Articulation('staccato')
    assert a.name_string == 'staccato'

    a.name_string = 'marcato'

    assert a.name_string == 'marcato'




from abjad import *
from abjad.tools import tonalitytools


def test_SuspensionIndicator_chord_name_string_01( ):

    t = tonalitytools.SuspensionIndicator(4, 3)
    assert t.chord_name_string == 'sus4'

    t = tonalitytools.SuspensionIndicator(('flat', 2), 1)
    assert t.chord_name_string == 'susb2'

    t = tonalitytools.SuspensionIndicator( )
    assert t.chord_name_string == ''



from abjad import *


def test_ClefMark_clef_name_string_01( ):
    '''Clef name string is read / write.
    '''

    clef = contexttools.ClefMark('treble')
    assert clef.clef_name_string == 'treble'

    clef.clef_name_string = 'alto'
    assert clef.clef_name_string == 'alto'





from abjad.tools import contexttools
from abjad.tools import pitchtools
from abjad.tools.instrumenttools._PercussionInstrument import _PercussionInstrument


class Xylophone(_PercussionInstrument):
    r'''.. versionadded:: 2.0

    Abjad model of the xylphone::

        abjad> staff = Staff("c'8 d'8 e'8 f'8")

    ::

        abjad> instrumenttools.Xylophone( )(staff)
        Xylophone('Xylophone', 'Xyl.')

    ::

        abjad> f(staff)
        \new Staff {
            \set Staff.instrumentName = \markup { Xylophone }
            \set Staff.shortInstrumentName = \markup { Xyl. }
            c'8
            d'8
            e'8
            f'8
        }

    The xylophone targets staff context by default.
    '''

    def __init__(self,
        instrument_name = 'Xylophone', short_instrument_name = 'Xyl.', target_context = None):
        _PercussionInstrument.__init__(self, instrument_name, short_instrument_name, target_context)
        self.sounding_pitch_of_fingered_middle_c = pitchtools.NamedChromaticPitch("c''")
        self.primary_clefs = [contexttools.ClefMark('treble')]
        self._copy_primary_clefs_to_all_clefs( )
        self.traditional_range = (0, 36)



from abjad import *


def test_instrumenttools_EFlatClarinet_sounding_pitch_of_fingered_middle_c_01( ):

    e_flat_clarinet = instrumenttools.EFlatClarinet( )

    assert e_flat_clarinet.sounding_pitch_of_fingered_middle_c == "ef'"



def iterate_sequence_nwise_cyclic(sequence, n):
    '''.. versionadded:: 2.0

    Iterate elements in `sequence` cyclically `n` at a time::

        abjad> from abjad.tools import seqtools

    ::

        abjad> g = seqtools.iterate_sequence_nwise_cyclic(range(6), 3)
        abjad> for n in range(10):
        ...   print g.next( )
        (0, 1, 2)
        (1, 2, 3)
        (2, 3, 4)
        (3, 4, 5)
        (4, 5, 0)
        (5, 0, 1)
        (0, 1, 2)
        (1, 2, 3)
        (2, 3, 4)
        (3, 4, 5)

    Return generator.
    '''

    buffer = [ ]
    long_enough = False
    for element in sequence:
        buffer.append(element)
        if not long_enough:
            if n <= len(buffer):
                long_enough = True
        if long_enough:
            yield tuple(buffer[-n:])

    len_sequence = len(buffer)
    cur = len_sequence - n + 1
    while True:
        output = [ ]
        for local_offset in range(n):
            index = (cur + local_offset) % len_sequence
            output.append(buffer[index])
        yield tuple(output)
        cur += 1
        cur %= len_sequence



from abjad import *
from abjad.tools import seqtools


def test_seqtools_all_are_positive_integer_equivalent_numbers_01( ):

    assert seqtools.all_are_positive_integer_equivalent_numbers([Fraction(4, 2), 2.0, 2])


def test_seqtools_all_are_positive_integer_equivalent_numbers_02( ):

    assert not seqtools.all_are_positive_integer_equivalent_numbers([Fraction(5, 2), 2.5, -2, 0])



from abjad import *
from abjad.tools import seqtools


def test_seqtools_repeat_sequence_to_weight_at_least_01( ):

    assert seqtools.repeat_sequence_to_weight_at_least((5, -5, -5), 23) == (5, -5, -5, 5, -5)



from abjad import *
from abjad.tools import metertools


def test_metertools_duration_and_possible_denominators_to_meter_01( ):
    '''Find only feasible denominator in denominators list.'''

    t = metertools.duration_and_possible_denominators_to_meter(Duration(3, 2), [5, 6, 7, 8, 9])
    assert t == contexttools.TimeSignatureMark(9, 6)


def test_metertools_duration_and_possible_denominators_to_meter_02( ):
    '''Use least feasible denominator in denominators list.'''

    t = metertools.duration_and_possible_denominators_to_meter(Duration(3, 2), [4, 8, 16, 32])
    assert t == contexttools.TimeSignatureMark(6, 4)


def test_metertools_duration_and_possible_denominators_to_meter_03( ):
    '''Make meter literally from duration.'''

    t = metertools.duration_and_possible_denominators_to_meter(Duration(3, 2))
    assert t == contexttools.TimeSignatureMark(3, 2)


def test_metertools_duration_and_possible_denominators_to_meter_04( ):
    '''Make meter literally from duration
        because no feasible denomiantors in denominators list.'''

    t = metertools.duration_and_possible_denominators_to_meter(Duration(3, 2), [7, 11, 13, 19])
    assert t == contexttools.TimeSignatureMark(3, 2)





from abjad import *


def test_durtools_Duration___init___01( ):

    duration = Duration(3, 5)
    assert isinstance(duration, Duration)

    duration = Duration((3, 5))
    assert isinstance(duration, Duration)




from abjad import *


def test_MultipartBeamSpanner___init___01( ):
    '''Init empty multipart beam spanner.
    '''

    beam = spannertools.MultipartBeamSpanner( )
    assert isinstance(beam, spannertools.MultipartBeamSpanner)






from abjad import *


def test_instrumenttools_Contrabassoon___init___01( ):

    contrabassoon = instrumenttools.Contrabassoon( )

    assert isinstance(contrabassoon, instrumenttools.Contrabassoon)



from abjad.cfg._read_config_file import _read_config_file
import os


### TODO: Call operating-specific view program instead of vi. ###

def log( ):
    '''Open the LilyPond log file in the ``vi``::

        abjad> iotools.log( ) ### doctest: +SKIP

    ::

        GNU LilyPond 2.12.2
        Processing `0440.ly'
        Parsing...
        Interpreting music...
        Preprocessing graphical objects...
        Finding the ideal number of pages...
        Fitting music on 1 page...
        Drawing systems...
        Layout output to `0440.ps'...
        Converting to `./0440.pdf'...

    Exit ``vi`` in the usual way with ``:q`` or equivalent to return to the Abjad interpreter.

    Return none.
    '''

    ABJADOUTPUT = _read_config_file( )['abjad_output']
    os.system('vi %s' % os.path.join(ABJADOUTPUT, 'lily.log'))



from abjad import *
from abjad.tools.marktools import Comment


def test_Comment___repr___01( ):
    '''Repr of unattached comment is evaluable.
    '''

    comment_1 = marktools.Comment('foo')
    comment_2 = eval(repr(comment_1))

    assert isinstance(comment_1, marktools.Comment)
    assert isinstance(comment_2, marktools.Comment)
    assert comment_1 == comment_2




from abjad import *
from abjad.tools import pitcharraytools
from abjad.tools.pitcharraytools import PitchArrayCell


def test_PitchArrayCell_pitches_01( ):

    array = pitcharraytools.PitchArray([[1, 2, 1], [2, 1, 1]])
    array[0].cells[0].pitches.append(pitchtools.NamedChromaticPitch(0))
    array[0].cells[1].pitches.append(pitchtools.NamedChromaticPitch(2))

    '''
    [c'] [d'     ] [ ]
    [         ] [ ] [ ]
    '''

    assert array[0].cells[0].pitches == [pitchtools.NamedChromaticPitch(0)]
    assert array[0].cells[1].pitches == [pitchtools.NamedChromaticPitch(2)]
    assert array[0].cells[2].pitches == [ ]

    assert array[1].cells[0].pitches == [ ]
    assert array[1].cells[1].pitches == [ ]
    assert array[1].cells[2].pitches == [ ]


def test_PitchArrayCell_pitches_02( ):

    cell = PitchArrayCell([pitchtools.NamedChromaticPitch(0)])

    assert cell.pitches == [pitchtools.NamedChromaticPitch(0)]



from abjad import *


def test_MelodicChromaticInterval___le___01( ):
    '''Compare two ascending chromatic intervals.'''

    interval_1 = pitchtools.MelodicChromaticInterval(2)
    interval_2 = pitchtools.MelodicChromaticInterval(6)

    assert interval_1 <= interval_2
    assert not interval_2 <= interval_1


def test_MelodicChromaticInterval___le___02( ):
    '''Compare two descending chromatic intervals.'''

    interval_1 = pitchtools.MelodicChromaticInterval(-2)
    interval_2 = pitchtools.MelodicChromaticInterval(-6)

    assert interval_1 <= interval_2
    assert not interval_2 <= interval_1


def test_MelodicChromaticInterval___le___03( ):
    '''Compare two ascending chromatic intervals.'''

    interval_1 = pitchtools.MelodicChromaticInterval(2)
    interval_2 = pitchtools.MelodicChromaticInterval(2)

    assert interval_1 <= interval_2
    assert interval_2 <= interval_1


def test_MelodicChromaticInterval___le___04( ):
    '''Compare two descending chromatic intervals.'''

    interval_1 = pitchtools.MelodicChromaticInterval(-2)
    interval_2 = pitchtools.MelodicChromaticInterval(-2)

    assert interval_1 <= interval_2
    assert interval_2 <= interval_1




from abjad import *


def test_MeasuredComplexBeamSpanner___init___01( ):
    '''Init empty measured complex beam spanner.
    '''

    beam = spannertools.MeasuredComplexBeamSpanner( )
    assert isinstance(beam, spannertools.MeasuredComplexBeamSpanner)






from abjad import *
from abjad.tools import tonalitytools


def test_QualityIndicator___eq___01( ):

    t = tonalitytools.QualityIndicator('major')
    u = tonalitytools.QualityIndicator('major')
    v = tonalitytools.QualityIndicator('minor')

    assert      t == t
    assert      t == u
    assert not t == v

    assert      u == t
    assert      u == u
    assert not u == v

    assert not v == t
    assert not v == u
    assert      v == v



from abjad import *


def test_HarmonicDiatonicIntervalClass_invert_01( ):

    hdic = pitchtools.HarmonicDiatonicIntervalClass('major', 2)
    inversion = pitchtools.HarmonicDiatonicIntervalClass('minor', 7)
    assert hdic.invert( ) == inversion

    hdic = pitchtools.HarmonicDiatonicIntervalClass('minor', 2)
    inversion = pitchtools.HarmonicDiatonicIntervalClass('major', 7)
    assert hdic.invert( ) == inversion


def test_HarmonicDiatonicIntervalClass_invert_02( ):

    hdic = pitchtools.HarmonicDiatonicIntervalClass('perfect', 4)
    inversion = pitchtools.HarmonicDiatonicIntervalClass('perfect', 5)
    assert hdic.invert( ) == inversion




from abjad.tools import mathtools


def get_nonbinary_factor_from_meter_denominator(meter):
    '''Get nonbinary factor from nonbinary `meter` denominator::

        abjad> from abjad.tools import metertools

    ::

        abjad> metertools.get_nonbinary_factor_from_meter_denominator(contexttools.TimeSignatureMark(3, 12))
        3

    ::

        abjad> metertools.get_nonbinary_factor_from_meter_denominator(contexttools.TimeSignatureMark(3, 13))
        13

    ::

        abjad> metertools.get_nonbinary_factor_from_meter_denominator(contexttools.TimeSignatureMark(3, 14))
        7

    ::

        abjad> metertools.get_nonbinary_factor_from_meter_denominator(contexttools.TimeSignatureMark(3, 15))
        15

    Get ``1`` from binary `meter` denominator::

        abjad> metertools.get_nonbinary_factor_from_meter_denominator(contexttools.TimeSignatureMark(3, 16))
        1

    Return nonnegative integer.
    '''
    from abjad.tools import contexttools

    ### check input
    assert isinstance(meter, contexttools.TimeSignatureMark)

    ### get nonbinary factor from meter denominator
    nonbinary_factor = mathtools.remove_powers_of_two(meter.denominator)

    ### return nonbinary factor
    return nonbinary_factor





from abjad.tools import seqtools
from abjad.tools.pitchtools.get_named_chromatic_pitch_from_pitch_carrier import get_named_chromatic_pitch_from_pitch_carrier
from abjad.tools.pitchtools.is_pitch_carrier import is_pitch_carrier


def list_inversion_equivalent_chromatic_interval_classes_pairwise_between_pitch_carriers(
    pitch_carriers, wrap = False):
    r'''.. versionadded:: 2.0

    List inversion-equivalent chromatic interval-classes pairwise between `pitch_carriers`::

        abjad> staff = Staff("c'8 d'8 e'8 f'8 g'8 a'8 b'8 c''8")

    ::

        abjad> f(staff)
        \new Staff {
            c'8
            d'8
            e'8
            f'8
            g'8
            a'8
            b'8
            c''8
        }

    ::

        abjad> pitchtools.list_inversion_equivalent_chromatic_interval_classes_pairwise_between_pitch_carriers(staff, wrap = False)
        [InversionEquivalentChromaticIntervalClass(2), InversionEquivalentChromaticIntervalClass(2), InversionEquivalentChromaticIntervalClass(1),
        InversionEquivalentChromaticIntervalClass(2), InversionEquivalentChromaticIntervalClass(2), InversionEquivalentChromaticIntervalClass(2),
        InversionEquivalentChromaticIntervalClass(1)]

    ::

        abjad> pitchtools.list_inversion_equivalent_chromatic_interval_classes_pairwise_between_pitch_carriers(staff, wrap = True)
        [InversionEquivalentChromaticIntervalClass(2), InversionEquivalentChromaticIntervalClass(2), InversionEquivalentChromaticIntervalClass(1),
        InversionEquivalentChromaticIntervalClass(2), InversionEquivalentChromaticIntervalClass(2), InversionEquivalentChromaticIntervalClass(2),
        InversionEquivalentChromaticIntervalClass(1), InversionEquivalentChromaticIntervalClass(0)]


    ::

        abjad> notes = [Note("c'8"), Note("d'8"), Note("e'8"), Note("f'8"), Note("g'8"), Note("a'8"), Note("b'8"), Note("c''8")]
        abjad> notes.reverse( )
        abjad> notes
        [Note("c''8"), Note("b'8"), Note("a'8"), Note("g'8"), Note("f'8"), Note("e'8"), Note("d'8"), Note("c'8")]

    ::

        abjad> pitchtools.list_inversion_equivalent_chromatic_interval_classes_pairwise_between_pitch_carriers(notes, wrap = False)
        [InversionEquivalentChromaticIntervalClass(1), InversionEquivalentChromaticIntervalClass(2), InversionEquivalentChromaticIntervalClass(2),
        InversionEquivalentChromaticIntervalClass(2), InversionEquivalentChromaticIntervalClass(1), InversionEquivalentChromaticIntervalClass(2),
        InversionEquivalentChromaticIntervalClass(2)]

    ::

        abjad> pitchtools.list_inversion_equivalent_chromatic_interval_classes_pairwise_between_pitch_carriers(notes, wrap = True)
        [InversionEquivalentChromaticIntervalClass(1), InversionEquivalentChromaticIntervalClass(2), InversionEquivalentChromaticIntervalClass(2),
        InversionEquivalentChromaticIntervalClass(2), InversionEquivalentChromaticIntervalClass(1), InversionEquivalentChromaticIntervalClass(2),
        InversionEquivalentChromaticIntervalClass(2), InversionEquivalentChromaticIntervalClass(0)]

    When ``wrap = False`` do not return ``pitch_carriers[-1] - pitch_carriers[0]`` as last in series.

    When ``wrap = True`` do return ``pitch_carriers[-1] - pitch_carriers[0]`` as last in series.

    Return list.
    '''

    result = [ ]

    if len(pitch_carriers) == 0:
        return result
    elif len(pitch_carriers) == 1:
        if is_pitch_carrier(pitch_carriers[0]):
            return result
        else:
            raise TypeError('must be Abjad Pitch, Note, NoteHead or Chord.')

    if wrap:
        pairs = seqtools.iterate_sequence_pairwise_wrapped(pitch_carriers)
    else:
        pairs = seqtools.iterate_sequence_pairwise_strict(pitch_carriers)

    for first_carrier, second_carrier in pairs:
        first_pitch = get_named_chromatic_pitch_from_pitch_carrier(first_carrier)
        second_pitch = get_named_chromatic_pitch_from_pitch_carrier(second_carrier)
        #signed_interval = abs(second_pitch.numbered_chromatic_pitch) - \
        #   abs(first_pitch.numbered_chromatic_pitch)
        #result.append(signed_interval)
        mdi = second_pitch - first_pitch
        iecic = mdi.inversion_equivalent_chromatic_interval_class
        result.append(iecic)

    return result




from abjad.tools.contexttools.get_time_signature_mark_attached_to_component import get_time_signature_mark_attached_to_component


def detach_time_signature_mark_attached_to_component(component):
    r'''.. versionadded:: 2.0

    Detach time signature mark attached to `component`::

        abjad> staff = Staff("c'4 d'4 e'4 f'4")
        abjad> contexttools.TimeSignatureMark(4, 4)(staff[0])
        TimeSignatureMark(4, 4)(c'4)

    ::

        abjad> f(staff)
        \new Staff {
            \time 4/4
            c'4
            d'4
            e'4
            f'4
        }

    ::

        abjad> contexttools.detach_time_signature_mark_attached_to_component(staff[0])
        TimeSignatureMark(4, 4)

    ::

        abjad> f(staff)
        \new Staff {
            c'4
            d'4
            e'4
            f'4
        }

    Return time signature mark.

    Raise missing mark error when no time signature mark attached to `component`.
    '''

    time_signature_mark = get_time_signature_mark_attached_to_component(component)

    return time_signature_mark.detach_mark( )





from abjad import *


def test_TempoMark___div___01( ):

    tempo_indication_1 = contexttools.TempoMark(Duration(1, 4), 60)
    tempo_indication_2 = contexttools.TempoMark(Duration(1, 4), 90)

    assert tempo_indication_2 / tempo_indication_1 == Duration(3, 2)
    assert tempo_indication_1 / tempo_indication_2 == Duration(2, 3)


def test_TempoMark___div___02( ):

    tempo_indication_1 = contexttools.TempoMark(Duration(1, 8), 42)
    tempo_indication_2 = contexttools.TempoMark(Duration(1, 4), 90)

    assert tempo_indication_2 / tempo_indication_1 == Duration(15, 14)
    assert tempo_indication_1 / tempo_indication_2 == Duration(14, 15)





from abjad import *
from abjad.tools import seqtools


def test_seqtools_split_sequence_extended_to_weights_without_overhang_01( ):

    parts = seqtools.split_sequence_extended_to_weights_without_overhang([1, 2, 3, 4, 5], [7, 7, 7])

    assert parts == [[1, 2, 3, 1], [3, 4], [1, 1, 2, 3]]



from abjad import *
from abjad.tools import seqtools


def test_seqtools_partition_sequence_by_value_of_elements_01( ):

    l = [ ]

    t = list(seqtools.partition_sequence_by_value_of_elements(l))
    assert t == [ ]


def test_seqtools_partition_sequence_by_value_of_elements_02( ):

    l = [1, 1, 1, 'a', 'a']

    t = list(seqtools.partition_sequence_by_value_of_elements(l))
    assert t == [(1, 1, 1), ('a', 'a')]


def test_seqtools_partition_sequence_by_value_of_elements_03( ):

    l = [0, 0, -1, -1, 2, 3, -5, 1, 1, 5, -5]

    t = list(seqtools.partition_sequence_by_value_of_elements(l))
    assert t == [(0, 0), (-1, -1), (2,), (3,), (-5,), (1, 1), (5,), (-5,)]



from abjad import *
from abjad.tools import seqtools


def test_seqtools_all_are_equal_01( ):
    '''True when all elements in sequence are equal.
    '''

    assert seqtools.all_are_equal([-1, -1, -1, -1, -1])
    assert seqtools.all_are_equal([0, 0, 0, 0, 0])
    assert seqtools.all_are_equal([1, 1, 1, 1, 1])
    assert seqtools.all_are_equal([2, 2, 2, 2, 2])


def test_seqtools_all_are_equal_02( ):
    '''True on empty sequence.
    '''

    assert seqtools.all_are_equal([ ])


def test_seqtools_all_are_equal_03( ):
    '''False otherwise.
    '''

    assert not seqtools.all_are_equal([-1, -1, -1, -1, 99])
    assert not seqtools.all_are_equal([0, 0, 0, 0, 99])
    assert not seqtools.all_are_equal([1, 1, 1, 1, 99])
    assert not seqtools.all_are_equal([2, 2, 2, 2, 99])


def test_seqtools_all_are_equal_04( ):
    '''False when expr is not a sequence.
    '''

    assert not seqtools.all_are_equal(17)



from xml.etree import ElementTree
import os


def _import_test_file( ):
    f = open(os.path.join(os.path.dirname(__file__), 'test', 'SchbAvMaSample.xml'), 'r')
    r = ElementTree.parse(f).getroot( )
    f.close( )
    return r




from abjad import *


def test_instrumenttools_Flute_interval_of_transposition_01( ):

    flute = instrumenttools.Flute( )

    assert flute.interval_of_transposition == pitchtools.MelodicDiatonicInterval('P1')



from abjad import *
from abjad.tools import seqtools


def test_seqtools_is_restricted_growth_function_01( ):

    assert seqtools.is_restricted_growth_function([1, 1, 1, 1])
    assert seqtools.is_restricted_growth_function([1, 1, 1, 2])
    assert seqtools.is_restricted_growth_function([1, 1, 2, 1])
    assert seqtools.is_restricted_growth_function([1, 1, 2, 2])
    assert seqtools.is_restricted_growth_function([1, 1, 2, 3])
    assert seqtools.is_restricted_growth_function([1, 2, 1, 1])
    assert seqtools.is_restricted_growth_function([1, 2, 1, 2])
    assert seqtools.is_restricted_growth_function([1, 2, 1, 3])
    assert seqtools.is_restricted_growth_function([1, 2, 2, 1])
    assert seqtools.is_restricted_growth_function([1, 2, 2, 2])
    assert seqtools.is_restricted_growth_function([1, 2, 2, 3])
    assert seqtools.is_restricted_growth_function([1, 2, 3, 1])
    assert seqtools.is_restricted_growth_function([1, 2, 3, 2])
    assert seqtools.is_restricted_growth_function([1, 2, 3, 3])
    assert seqtools.is_restricted_growth_function([1, 2, 3, 4])


def test_seqtools_is_restricted_growth_function_02( ):

    assert not seqtools.is_restricted_growth_function([1, 1, 1, 3])
    assert not seqtools.is_restricted_growth_function([1, 1, 3, 3])
    assert not seqtools.is_restricted_growth_function([1, 3, 1, 3])
    assert not seqtools.is_restricted_growth_function([3, 1, 1, 3])



from abjad import *


def test_MelodicDiatonicIntervalSet_harmonic_diatonic_interval_set_01( ):

    mdiset = pitchtools.MelodicDiatonicIntervalSet([
        pitchtools.MelodicDiatonicInterval('minor', -2),
        pitchtools.MelodicDiatonicInterval('major', -2),
        pitchtools.MelodicDiatonicInterval('minor', 2),
        pitchtools.MelodicDiatonicInterval('major', 2)])
    "MelodicDiatonicIntervalSet(-m2, -M2, +M2, +m2)"

    derived_hdiset = mdiset.harmonic_diatonic_interval_set
    manual_hdiset = pitchtools.HarmonicDiatonicIntervalSet([
        pitchtools.HarmonicDiatonicInterval('minor', 2),
        pitchtools.HarmonicDiatonicInterval('major', 2)])

    assert derived_hdiset == manual_hdiset




from abjad import *
from abjad.tools import seqtools


def test_seqtools_iterate_sequence_nwise_cyclic_01( ):

    g = seqtools.iterate_sequence_nwise_cyclic(range(6), 3)

    assert g.next( ) == (0, 1, 2)
    assert g.next( ) == (1, 2, 3)
    assert g.next( ) == (2, 3, 4)
    assert g.next( ) == (3, 4, 5)
    assert g.next( ) == (4, 5, 0)
    assert g.next( ) == (5, 0, 1)
    assert g.next( ) == (0, 1, 2)
    assert g.next( ) == (1, 2, 3)
    assert g.next( ) == (2, 3, 4)
    assert g.next( ) == (3, 4, 5)



from abjad.tools.intervaltreetools import BoundedInterval


def test_BoundedInterval___eq___01( ):
    a = BoundedInterval(0, 10)
    b = BoundedInterval(0, 10)
    assert a == b


def test_BoundedInterval___eq___02( ):
    a = BoundedInterval(0, 10)
    b = BoundedInterval(-1, 10)
    assert a != b


def test_BoundedInterval___eq___03( ):
    a = BoundedInterval(0, 10)
    b = BoundedInterval(0, 11)
    assert a != b


def test_BoundedInterval___eq___04( ):
    a = BoundedInterval(0, 10)
    b = BoundedInterval(0, 10, { })
    assert a == b


def test_BoundedInterval___eq___05( ):
    a = BoundedInterval(0, 10, {'animal': 'goose'})
    b = BoundedInterval(0, 10, {'animal': 'duck'})
    assert a != b



from abjad import *
from abjad.tools import seqtools


def test_seqtools_all_are_assignable_integers_01( ):
    '''True when all elements in sequence are all notehead assignable.
    '''

    assert seqtools.all_are_assignable_integers([1, 2, 3, 4, 6, 7, 8, 12, 14, 15, 16])


def test_seqtools_all_are_assignable_integers_02( ):
    '''True on empty sequence.
    '''

    assert seqtools.all_are_assignable_integers([ ])


def test_seqtools_all_are_assignable_integers_03( ):
    '''False otherwise.
    '''

    assert not seqtools.all_are_assignable_integers([0, 1, 2, 4, 5])


def test_seqtools_all_are_assignable_integers_04( ):
    '''False when expr is not a sequence.'''

    assert not seqtools.all_are_assignable_integers(16)
